from typing import Optional

from .codes import STEAM_ERROR_CODES
from .exceptions import (
    _CUSTOM_ERROR_EXCEPTIONS,
    SteamError,
    UnknownSteamError,
)


def check_steam_error(error: int, error_msg: Optional[str] = None) -> None:
    if error in (1, 22):
        return
    if error in _CUSTOM_ERROR_EXCEPTIONS:
        raise _CUSTOM_ERROR_EXCEPTIONS[error](error, error_msg)
    if error in STEAM_ERROR_CODES:
        raise SteamError(error_code=error, error_msg=error_msg)
    raise UnknownSteamError(error_code=error, error_msg=error_msg)



from typing import (
    List,
    Optional,
)

from pydantic import BaseModel


class AuthenticatorData(BaseModel):
    shared_secret: str
    identity_secret: str
    device_id: str


class Params(BaseModel):
    nonce: str
    auth: str


class TransferInfoItem(BaseModel):
    url: str
    params: Params


class FinalizeLoginStatus(BaseModel):
    steamID: str
    redir: str
    transfer_info: List[TransferInfoItem]
    primary_domain: str


class ServerTime(BaseModel):
    server_time: int
    skew_tolerance_seconds: int
    large_time_jink: int
    probe_frequency_seconds: int
    adjusted_time_probe_frequency_seconds: int
    hint_probe_frequency_seconds: int
    sync_timeout: int
    try_again_seconds: int
    max_attempts: int


class ServerTimeResponse(BaseModel):
    response: ServerTime


class SteamAuthorizationStatus(BaseModel):
    logged_in: bool
    steamid: str
    accountid: int
    account_name: str
    token: Optional[str]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_base.proto
# flake8: noqa
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import enum_type_wrapper


# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18steammessages_base.proto\x1a google/protobuf/descriptor.proto\"1\n\rCMsgIPAddress\x12\x0c\n\x02v4\x18\x01 \x01(\x07H\x00\x12\x0c\n\x02v6\x18\x02 \x01(\x0cH\x00\x42\x04\n\x02ip\"R\n\x13\x43MsgIPAddressBucket\x12+\n\x13original_ip_address\x18\x01 \x01(\x0b\x32\x0e.CMsgIPAddress\x12\x0e\n\x06\x62ucket\x18\x02 \x01(\x06\"\xf2\x05\n\x12\x43MsgProtoBufHeader\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x18\n\x10\x63lient_sessionid\x18\x02 \x01(\x05\x12\x15\n\rrouting_appid\x18\x03 \x01(\r\x12*\n\x0cjobid_source\x18\n \x01(\x06:\x14\x31\x38\x34\x34\x36\x37\x34\x34\x30\x37\x33\x37\x30\x39\x35\x35\x31\x36\x31\x35\x12*\n\x0cjobid_target\x18\x0b \x01(\x06:\x14\x31\x38\x34\x34\x36\x37\x34\x34\x30\x37\x33\x37\x30\x39\x35\x35\x31\x36\x31\x35\x12\x17\n\x0ftarget_job_name\x18\x0c \x01(\t\x12\x0f\n\x07seq_num\x18\x18 \x01(\x05\x12\x12\n\x07\x65result\x18\r \x01(\x05:\x01\x32\x12\x15\n\rerror_message\x18\x0e \x01(\t\x12\x1a\n\x12\x61uth_account_flags\x18\x10 \x01(\r\x12\x14\n\x0ctoken_source\x18\x16 \x01(\r\x12\x1b\n\x13\x61\x64min_spoofing_user\x18\x17 \x01(\x08\x12\x1a\n\x0ftransport_error\x18\x11 \x01(\x05:\x01\x31\x12\'\n\tmessageid\x18\x12 \x01(\x04:\x14\x31\x38\x34\x34\x36\x37\x34\x34\x30\x37\x33\x37\x30\x39\x35\x35\x31\x36\x31\x35\x12\x1a\n\x12publisher_group_id\x18\x13 \x01(\r\x12\r\n\x05sysid\x18\x14 \x01(\r\x12\x11\n\ttrace_tag\x18\x15 \x01(\x04\x12\x15\n\rwebapi_key_id\x18\x19 \x01(\r\x12\x1f\n\x17is_from_external_source\x18\x1a \x01(\x08\x12\x18\n\x10\x66orward_to_sysid\x18\x1b \x03(\r\x12\x10\n\x08\x63m_sysid\x18\x1c \x01(\r\x12\x18\n\rlauncher_type\x18\x1f \x01(\r:\x01\x30\x12\x10\n\x05realm\x18  \x01(\r:\x01\x30\x12\x16\n\ntimeout_ms\x18! \x01(\x05:\x02-1\x12\x14\n\x0c\x64\x65\x62ug_source\x18\" \x01(\t\x12!\n\x19\x64\x65\x62ug_source_string_index\x18# \x01(\r\x12\x10\n\x08token_id\x18$ \x01(\x04\x12\x0c\n\x02ip\x18\x0f \x01(\rH\x00\x12\x0f\n\x05ip_v6\x18\x1d \x01(\x0cH\x00\x42\t\n\x07ip_addr\"8\n\tCMsgMulti\x12\x15\n\rsize_unzipped\x18\x01 \x01(\r\x12\x14\n\x0cmessage_body\x18\x02 \x01(\x0c\"+\n\x13\x43MsgProtobufWrapped\x12\x14\n\x0cmessage_body\x18\x01 \x01(\x0c\"\x8f\x01\n\x0e\x43MsgAuthTicket\x12\x0e\n\x06\x65state\x18\x01 \x01(\r\x12\x12\n\x07\x65result\x18\x02 \x01(\r:\x01\x32\x12\x0f\n\x07steamid\x18\x03 \x01(\x06\x12\x0e\n\x06gameid\x18\x04 \x01(\x06\x12\x14\n\x0ch_steam_pipe\x18\x05 \x01(\r\x12\x12\n\nticket_crc\x18\x06 \x01(\r\x12\x0e\n\x06ticket\x18\x07 \x01(\x0c\"\x89\x02\n\x14\x43\x43\x44\x44\x42\x41ppDetailCommon\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\x0c\n\x04tool\x18\x06 \x01(\x08\x12\x0c\n\x04\x64\x65mo\x18\x07 \x01(\x08\x12\r\n\x05media\x18\x08 \x01(\x08\x12\x1f\n\x17\x63ommunity_visible_stats\x18\t \x01(\x08\x12\x15\n\rfriendly_name\x18\n \x01(\t\x12\x13\n\x0bpropagation\x18\x0b \x01(\t\x12\x19\n\x11has_adult_content\x18\x0c \x01(\x08\x12!\n\x19is_visible_in_steam_china\x18\r \x01(\x08\x12\x10\n\x08\x61pp_type\x18\x0e \x01(\r\"\xb3\x03\n\rCMsgAppRights\x12\x11\n\tedit_info\x18\x01 \x01(\x08\x12\x0f\n\x07publish\x18\x02 \x01(\x08\x12\x17\n\x0fview_error_data\x18\x03 \x01(\x08\x12\x10\n\x08\x64ownload\x18\x04 \x01(\x08\x12\x15\n\rupload_cdkeys\x18\x05 \x01(\x08\x12\x17\n\x0fgenerate_cdkeys\x18\x06 \x01(\x08\x12\x17\n\x0fview_financials\x18\x07 \x01(\x08\x12\x12\n\nmanage_ceg\x18\x08 \x01(\x08\x12\x16\n\x0emanage_signing\x18\t \x01(\x08\x12\x15\n\rmanage_cdkeys\x18\n \x01(\x08\x12\x16\n\x0e\x65\x64it_marketing\x18\x0b \x01(\x08\x12\x17\n\x0f\x65\x63onomy_support\x18\x0c \x01(\x08\x12\"\n\x1a\x65\x63onomy_support_supervisor\x18\r \x01(\x08\x12\x16\n\x0emanage_pricing\x18\x0e \x01(\x08\x12\x16\n\x0e\x62roadcast_live\x18\x0f \x01(\x08\x12\x1e\n\x16view_marketing_traffic\x18\x10 \x01(\x08\x12\"\n\x1a\x65\x64it_store_display_content\x18\x11 \x01(\x08\"\xf1\x02\n\x13\x43\x43uratorPreferences\x12\x1b\n\x13supported_languages\x18\x01 \x01(\r\x12\x18\n\x10platform_windows\x18\x02 \x01(\x08\x12\x14\n\x0cplatform_mac\x18\x03 \x01(\x08\x12\x16\n\x0eplatform_linux\x18\x04 \x01(\x08\x12\x12\n\nvr_content\x18\x05 \x01(\x08\x12\x1e\n\x16\x61\x64ult_content_violence\x18\x06 \x01(\x08\x12\x19\n\x11\x61\x64ult_content_sex\x18\x07 \x01(\x08\x12\x19\n\x11timestamp_updated\x18\x08 \x01(\r\x12\x16\n\x0etagids_curated\x18\t \x03(\r\x12\x17\n\x0ftagids_filtered\x18\n \x03(\r\x12\x15\n\rwebsite_title\x18\x0b \x01(\t\x12\x13\n\x0bwebsite_url\x18\x0c \x01(\t\x12\x16\n\x0e\x64iscussion_url\x18\r \x01(\t\x12\x16\n\x0eshow_broadcast\x18\x0e \x01(\x08\"@\n\x12\x43LocalizationToken\x12\x10\n\x08language\x18\x01 \x01(\r\x12\x18\n\x10localized_string\x18\x02 \x01(\t\"\xec\x01\n\x17\x43\x43lanEventUserNewsTuple\x12\x0e\n\x06\x63lanid\x18\x01 \x01(\r\x12\x11\n\tevent_gid\x18\x02 \x01(\x06\x12\x18\n\x10\x61nnouncement_gid\x18\x03 \x01(\x06\x12\x13\n\x0brtime_start\x18\x04 \x01(\r\x12\x11\n\trtime_end\x18\x05 \x01(\r\x12\x16\n\x0epriority_score\x18\x06 \x01(\r\x12\x0c\n\x04type\x18\x07 \x01(\r\x12\x18\n\x10\x63lamp_range_slot\x18\x08 \x01(\r\x12\r\n\x05\x61ppid\x18\t \x01(\r\x12\x1d\n\x15rtime32_last_modified\x18\n \x01(\r\"\x80\x01\n\x16\x43\x43lanMatchEventByRange\x12\x14\n\x0crtime_before\x18\x01 \x01(\r\x12\x13\n\x0brtime_after\x18\x02 \x01(\r\x12\x11\n\tqualified\x18\x03 \x01(\r\x12(\n\x06\x65vents\x18\x04 \x03(\x0b\x32\x18.CClanEventUserNewsTuple\"\x8b\x03\n\x1f\x43\x43ommunity_ClanAnnouncementInfo\x12\x0b\n\x03gid\x18\x01 \x01(\x04\x12\x0e\n\x06\x63lanid\x18\x02 \x01(\x04\x12\x10\n\x08posterid\x18\x03 \x01(\x04\x12\x10\n\x08headline\x18\x04 \x01(\t\x12\x10\n\x08posttime\x18\x05 \x01(\r\x12\x12\n\nupdatetime\x18\x06 \x01(\r\x12\x0c\n\x04\x62ody\x18\x07 \x01(\t\x12\x14\n\x0c\x63ommentcount\x18\x08 \x01(\x05\x12\x0c\n\x04tags\x18\t \x03(\t\x12\x10\n\x08language\x18\n \x01(\x05\x12\x0e\n\x06hidden\x18\x0b \x01(\x08\x12\x16\n\x0e\x66orum_topic_id\x18\x0c \x01(\x06\x12\x11\n\tevent_gid\x18\r \x01(\x06\x12\x13\n\x0bvoteupcount\x18\x0e \x01(\x05\x12\x15\n\rvotedowncount\x18\x0f \x01(\x05\x12V\n\x10\x62\x61n_check_result\x18\x10 \x01(\x0e\x32\x17.EBanContentCheckResult:#k_EBanContentCheckResult_NotScanned\"\xa6\x06\n\x0e\x43\x43lanEventData\x12\x0b\n\x03gid\x18\x01 \x01(\x06\x12\x14\n\x0c\x63lan_steamid\x18\x02 \x01(\x06\x12\x12\n\nevent_name\x18\x03 \x01(\t\x12;\n\nevent_type\x18\x04 \x01(\x0e\x32\x14.EProtoClanEventType:\x11k_EClanOtherEvent\x12\r\n\x05\x61ppid\x18\x05 \x01(\r\x12\x16\n\x0eserver_address\x18\x06 \x01(\t\x12\x17\n\x0fserver_password\x18\x07 \x01(\t\x12\x1a\n\x12rtime32_start_time\x18\x08 \x01(\r\x12\x18\n\x10rtime32_end_time\x18\t \x01(\r\x12\x15\n\rcomment_count\x18\n \x01(\x05\x12\x17\n\x0f\x63reator_steamid\x18\x0b \x01(\x06\x12\x1b\n\x13last_update_steamid\x18\x0c \x01(\x06\x12\x13\n\x0b\x65vent_notes\x18\r \x01(\t\x12\x10\n\x08jsondata\x18\x0e \x01(\t\x12;\n\x11\x61nnouncement_body\x18\x0f \x01(\x0b\x32 .CCommunity_ClanAnnouncementInfo\x12\x11\n\tpublished\x18\x10 \x01(\x08\x12\x0e\n\x06hidden\x18\x11 \x01(\x08\x12 \n\x18rtime32_visibility_start\x18\x12 \x01(\r\x12\x1e\n\x16rtime32_visibility_end\x18\x13 \x01(\r\x12\x1d\n\x15\x62roadcaster_accountid\x18\x14 \x01(\r\x12\x16\n\x0e\x66ollower_count\x18\x15 \x01(\r\x12\x14\n\x0cignore_count\x18\x16 \x01(\r\x12\x16\n\x0e\x66orum_topic_id\x18\x17 \x01(\x06\x12\x1d\n\x15rtime32_last_modified\x18\x18 \x01(\r\x12\x15\n\rnews_post_gid\x18\x19 \x01(\x06\x12\x1a\n\x12rtime_mod_reviewed\x18\x1a \x01(\r\x12\x1a\n\x12\x66\x65\x61tured_app_tagid\x18\x1b \x01(\r\x12\x19\n\x11referenced_appids\x18\x1c \x03(\r\x12\x10\n\x08\x62uild_id\x18\x1d \x01(\r\x12\x14\n\x0c\x62uild_branch\x18\x1e \x01(\t\"\xc7\x01\n\x10\x43\x42illing_Address\x12\x12\n\nfirst_name\x18\x01 \x01(\t\x12\x11\n\tlast_name\x18\x02 \x01(\t\x12\x10\n\x08\x61\x64\x64ress1\x18\x03 \x01(\t\x12\x10\n\x08\x61\x64\x64ress2\x18\x04 \x01(\t\x12\x0c\n\x04\x63ity\x18\x05 \x01(\t\x12\x10\n\x08us_state\x18\x06 \x01(\t\x12\x14\n\x0c\x63ountry_code\x18\x07 \x01(\t\x12\x10\n\x08postcode\x18\x08 \x01(\t\x12\x11\n\tzip_plus4\x18\t \x01(\x05\x12\r\n\x05phone\x18\n \x01(\t\"\xdb\x01\n\x19\x43PackageReservationStatus\x12\x11\n\tpackageid\x18\x01 \x01(\r\x12\x19\n\x11reservation_state\x18\x02 \x01(\x05\x12\x16\n\x0equeue_position\x18\x03 \x01(\x05\x12\x18\n\x10total_queue_size\x18\x04 \x01(\x05\x12 \n\x18reservation_country_code\x18\x05 \x01(\t\x12\x0f\n\x07\x65xpired\x18\x06 \x01(\x08\x12\x14\n\x0ctime_expires\x18\x07 \x01(\r\x12\x15\n\rtime_reserved\x18\x08 \x01(\r\"/\n\x10\x43MsgKeyValuePair\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"3\n\x0f\x43MsgKeyValueSet\x12 \n\x05pairs\x18\x01 \x03(\x0b\x32\x11.CMsgKeyValuePair*\xd8\x02\n\x16\x45\x42\x61nContentCheckResult\x12\'\n#k_EBanContentCheckResult_NotScanned\x10\x00\x12\"\n\x1ek_EBanContentCheckResult_Reset\x10\x01\x12*\n&k_EBanContentCheckResult_NeedsChecking\x10\x02\x12)\n%k_EBanContentCheckResult_VeryUnlikely\x10\x05\x12%\n!k_EBanContentCheckResult_Unlikely\x10\x1e\x12%\n!k_EBanContentCheckResult_Possible\x10\x32\x12#\n\x1fk_EBanContentCheckResult_Likely\x10K\x12\'\n#k_EBanContentCheckResult_VeryLikely\x10\x64*\xeb\x07\n\x13\x45ProtoClanEventType\x12\x15\n\x11k_EClanOtherEvent\x10\x01\x12\x14\n\x10k_EClanGameEvent\x10\x02\x12\x15\n\x11k_EClanPartyEvent\x10\x03\x12\x17\n\x13k_EClanMeetingEvent\x10\x04\x12\x1c\n\x18k_EClanSpecialCauseEvent\x10\x05\x12\x1c\n\x18k_EClanMusicAndArtsEvent\x10\x06\x12\x16\n\x12k_EClanSportsEvent\x10\x07\x12\x14\n\x10k_EClanTripEvent\x10\x08\x12\x14\n\x10k_EClanChatEvent\x10\t\x12\x1b\n\x17k_EClanGameReleaseEvent\x10\n\x12\x19\n\x15k_EClanBroadcastEvent\x10\x0b\x12\x1b\n\x17k_EClanSmallUpdateEvent\x10\x0c\x12&\n\"k_EClanPreAnnounceMajorUpdateEvent\x10\r\x12\x1b\n\x17k_EClanMajorUpdateEvent\x10\x0e\x12\x1a\n\x16k_EClanDLCReleaseEvent\x10\x0f\x12\x1d\n\x19k_EClanFutureReleaseEvent\x10\x10\x12&\n\"k_EClanESportTournamentStreamEvent\x10\x11\x12\x19\n\x15k_EClanDevStreamEvent\x10\x12\x12\x1c\n\x18k_EClanFamousStreamEvent\x10\x13\x12\x19\n\x15k_EClanGameSalesEvent\x10\x14\x12\x1d\n\x19k_EClanGameItemSalesEvent\x10\x15\x12\x1d\n\x19k_EClanInGameBonusXPEvent\x10\x16\x12\x1a\n\x16k_EClanInGameLootEvent\x10\x17\x12\x1b\n\x17k_EClanInGamePerksEvent\x10\x18\x12\x1f\n\x1bk_EClanInGameChallengeEvent\x10\x19\x12\x1d\n\x19k_EClanInGameContestEvent\x10\x1a\x12\x13\n\x0fk_EClanIRLEvent\x10\x1b\x12\x14\n\x10k_EClanNewsEvent\x10\x1c\x12\x1b\n\x17k_EClanBetaReleaseEvent\x10\x1d\x12$\n k_EClanInGameContentReleaseEvent\x10\x1e\x12\x14\n\x10k_EClanFreeTrial\x10\x1f\x12\x18\n\x14k_EClanSeasonRelease\x10 \x12\x17\n\x13k_EClanSeasonUpdate\x10!\x12\x19\n\x15k_EClanCrosspostEvent\x10\"\x12\x1d\n\x19k_EClanInGameEventGeneral\x10#*\x81\x01\n\x1cPartnerEventNotificationType\x12\x11\n\rk_EEventStart\x10\x00\x12\x1a\n\x16k_EEventBroadcastStart\x10\x01\x12\x16\n\x12k_EEventMatchStart\x10\x02\x12\x1a\n\x16k_EEventPartnerMaxType\x10\x03:A\n\x12msgpool_soft_limit\x12\x1f.google.protobuf.MessageOptions\x18\xd0\x86\x03 \x01(\x05:\x02\x33\x32:B\n\x12msgpool_hard_limit\x12\x1f.google.protobuf.MessageOptions\x18\xd1\x86\x03 \x01(\x05:\x03\x33\x38\x34:C\n\x14\x66orce_php_generation\x12\x1c.google.protobuf.FileOptions\x18\xd0\x86\x03 \x01(\x08:\x05\x66\x61lse:H\n\x18php_output_always_number\x12\x1d.google.protobuf.FieldOptions\x18\xe4\x86\x03 \x01(\x08:\x05\x66\x61lse:J\n\x1a\x61llow_field_named_steam_id\x12\x1d.google.protobuf.FieldOptions\x18\xe8\x86\x03 \x01(\x08:\x05\x66\x61lseB\tH\x01\x80\x01\x01\x80\xb5\x18\x01')

_EBANCONTENTCHECKRESULT = DESCRIPTOR.enum_types_by_name['EBanContentCheckResult']
EBanContentCheckResult = enum_type_wrapper.EnumTypeWrapper(
    _EBANCONTENTCHECKRESULT)
_EPROTOCLANEVENTTYPE = DESCRIPTOR.enum_types_by_name['EProtoClanEventType']
EProtoClanEventType = enum_type_wrapper.EnumTypeWrapper(_EPROTOCLANEVENTTYPE)
_PARTNEREVENTNOTIFICATIONTYPE = DESCRIPTOR.enum_types_by_name['PartnerEventNotificationType']
PartnerEventNotificationType = enum_type_wrapper.EnumTypeWrapper(
    _PARTNEREVENTNOTIFICATIONTYPE)
k_EBanContentCheckResult_NotScanned = 0
k_EBanContentCheckResult_Reset = 1
k_EBanContentCheckResult_NeedsChecking = 2
k_EBanContentCheckResult_VeryUnlikely = 5
k_EBanContentCheckResult_Unlikely = 30
k_EBanContentCheckResult_Possible = 50
k_EBanContentCheckResult_Likely = 75
k_EBanContentCheckResult_VeryLikely = 100
k_EClanOtherEvent = 1
k_EClanGameEvent = 2
k_EClanPartyEvent = 3
k_EClanMeetingEvent = 4
k_EClanSpecialCauseEvent = 5
k_EClanMusicAndArtsEvent = 6
k_EClanSportsEvent = 7
k_EClanTripEvent = 8
k_EClanChatEvent = 9
k_EClanGameReleaseEvent = 10
k_EClanBroadcastEvent = 11
k_EClanSmallUpdateEvent = 12
k_EClanPreAnnounceMajorUpdateEvent = 13
k_EClanMajorUpdateEvent = 14
k_EClanDLCReleaseEvent = 15
k_EClanFutureReleaseEvent = 16
k_EClanESportTournamentStreamEvent = 17
k_EClanDevStreamEvent = 18
k_EClanFamousStreamEvent = 19
k_EClanGameSalesEvent = 20
k_EClanGameItemSalesEvent = 21
k_EClanInGameBonusXPEvent = 22
k_EClanInGameLootEvent = 23
k_EClanInGamePerksEvent = 24
k_EClanInGameChallengeEvent = 25
k_EClanInGameContestEvent = 26
k_EClanIRLEvent = 27
k_EClanNewsEvent = 28
k_EClanBetaReleaseEvent = 29
k_EClanInGameContentReleaseEvent = 30
k_EClanFreeTrial = 31
k_EClanSeasonRelease = 32
k_EClanSeasonUpdate = 33
k_EClanCrosspostEvent = 34
k_EClanInGameEventGeneral = 35
k_EEventStart = 0
k_EEventBroadcastStart = 1
k_EEventMatchStart = 2
k_EEventPartnerMaxType = 3

MSGPOOL_SOFT_LIMIT_FIELD_NUMBER = 50000
msgpool_soft_limit = DESCRIPTOR.extensions_by_name['msgpool_soft_limit']
MSGPOOL_HARD_LIMIT_FIELD_NUMBER = 50001
msgpool_hard_limit = DESCRIPTOR.extensions_by_name['msgpool_hard_limit']
FORCE_PHP_GENERATION_FIELD_NUMBER = 50000
force_php_generation = DESCRIPTOR.extensions_by_name['force_php_generation']
PHP_OUTPUT_ALWAYS_NUMBER_FIELD_NUMBER = 50020
php_output_always_number = DESCRIPTOR.extensions_by_name['php_output_always_number']
ALLOW_FIELD_NAMED_STEAM_ID_FIELD_NUMBER = 50024
allow_field_named_steam_id = DESCRIPTOR.extensions_by_name['allow_field_named_steam_id']

_CMSGIPADDRESS = DESCRIPTOR.message_types_by_name['CMsgIPAddress']
_CMSGIPADDRESSBUCKET = DESCRIPTOR.message_types_by_name['CMsgIPAddressBucket']
_CMSGPROTOBUFHEADER = DESCRIPTOR.message_types_by_name['CMsgProtoBufHeader']
_CMSGMULTI = DESCRIPTOR.message_types_by_name['CMsgMulti']
_CMSGPROTOBUFWRAPPED = DESCRIPTOR.message_types_by_name['CMsgProtobufWrapped']
_CMSGAUTHTICKET = DESCRIPTOR.message_types_by_name['CMsgAuthTicket']
_CCDDBAPPDETAILCOMMON = DESCRIPTOR.message_types_by_name['CCDDBAppDetailCommon']
_CMSGAPPRIGHTS = DESCRIPTOR.message_types_by_name['CMsgAppRights']
_CCURATORPREFERENCES = DESCRIPTOR.message_types_by_name['CCuratorPreferences']
_CLOCALIZATIONTOKEN = DESCRIPTOR.message_types_by_name['CLocalizationToken']
_CCLANEVENTUSERNEWSTUPLE = DESCRIPTOR.message_types_by_name['CClanEventUserNewsTuple']
_CCLANMATCHEVENTBYRANGE = DESCRIPTOR.message_types_by_name['CClanMatchEventByRange']
_CCOMMUNITY_CLANANNOUNCEMENTINFO = DESCRIPTOR.message_types_by_name[
    'CCommunity_ClanAnnouncementInfo']
_CCLANEVENTDATA = DESCRIPTOR.message_types_by_name['CClanEventData']
_CBILLING_ADDRESS = DESCRIPTOR.message_types_by_name['CBilling_Address']
_CPACKAGERESERVATIONSTATUS = DESCRIPTOR.message_types_by_name['CPackageReservationStatus']
_CMSGKEYVALUEPAIR = DESCRIPTOR.message_types_by_name['CMsgKeyValuePair']
_CMSGKEYVALUESET = DESCRIPTOR.message_types_by_name['CMsgKeyValueSet']
CMsgIPAddress = _reflection.GeneratedProtocolMessageType('CMsgIPAddress', (_message.Message,), {
    'DESCRIPTOR': _CMSGIPADDRESS,
    '__module__': 'steammessages_base_pb2'
    # @@protoc_insertion_point(class_scope:CMsgIPAddress)
})
_sym_db.RegisterMessage(CMsgIPAddress)

CMsgIPAddressBucket = _reflection.GeneratedProtocolMessageType('CMsgIPAddressBucket', (_message.Message,), {
    'DESCRIPTOR': _CMSGIPADDRESSBUCKET,
    '__module__': 'steammessages_base_pb2'
    # @@protoc_insertion_point(class_scope:CMsgIPAddressBucket)
})
_sym_db.RegisterMessage(CMsgIPAddressBucket)

CMsgProtoBufHeader = _reflection.GeneratedProtocolMessageType('CMsgProtoBufHeader', (_message.Message,), {
    'DESCRIPTOR': _CMSGPROTOBUFHEADER,
    '__module__': 'steammessages_base_pb2'
    # @@protoc_insertion_point(class_scope:CMsgProtoBufHeader)
})
_sym_db.RegisterMessage(CMsgProtoBufHeader)

CMsgMulti = _reflection.GeneratedProtocolMessageType('CMsgMulti', (_message.Message,), {
    'DESCRIPTOR': _CMSGMULTI,
    '__module__': 'steammessages_base_pb2'
    # @@protoc_insertion_point(class_scope:CMsgMulti)
})
_sym_db.RegisterMessage(CMsgMulti)

CMsgProtobufWrapped = _reflection.GeneratedProtocolMessageType('CMsgProtobufWrapped', (_message.Message,), {
    'DESCRIPTOR': _CMSGPROTOBUFWRAPPED,
    '__module__': 'steammessages_base_pb2'
    # @@protoc_insertion_point(class_scope:CMsgProtobufWrapped)
})
_sym_db.RegisterMessage(CMsgProtobufWrapped)

CMsgAuthTicket = _reflection.GeneratedProtocolMessageType('CMsgAuthTicket', (_message.Message,), {
    'DESCRIPTOR': _CMSGAUTHTICKET,
    '__module__': 'steammessages_base_pb2'
    # @@protoc_insertion_point(class_scope:CMsgAuthTicket)
})
_sym_db.RegisterMessage(CMsgAuthTicket)

CCDDBAppDetailCommon = _reflection.GeneratedProtocolMessageType('CCDDBAppDetailCommon', (_message.Message,), {
    'DESCRIPTOR': _CCDDBAPPDETAILCOMMON,
    '__module__': 'steammessages_base_pb2'
    # @@protoc_insertion_point(class_scope:CCDDBAppDetailCommon)
})
_sym_db.RegisterMessage(CCDDBAppDetailCommon)

CMsgAppRights = _reflection.GeneratedProtocolMessageType('CMsgAppRights', (_message.Message,), {
    'DESCRIPTOR': _CMSGAPPRIGHTS,
    '__module__': 'steammessages_base_pb2'
    # @@protoc_insertion_point(class_scope:CMsgAppRights)
})
_sym_db.RegisterMessage(CMsgAppRights)

CCuratorPreferences = _reflection.GeneratedProtocolMessageType('CCuratorPreferences', (_message.Message,), {
    'DESCRIPTOR': _CCURATORPREFERENCES,
    '__module__': 'steammessages_base_pb2'
    # @@protoc_insertion_point(class_scope:CCuratorPreferences)
})
_sym_db.RegisterMessage(CCuratorPreferences)

CLocalizationToken = _reflection.GeneratedProtocolMessageType('CLocalizationToken', (_message.Message,), {
    'DESCRIPTOR': _CLOCALIZATIONTOKEN,
    '__module__': 'steammessages_base_pb2'
    # @@protoc_insertion_point(class_scope:CLocalizationToken)
})
_sym_db.RegisterMessage(CLocalizationToken)

CClanEventUserNewsTuple = _reflection.GeneratedProtocolMessageType('CClanEventUserNewsTuple', (_message.Message,), {
    'DESCRIPTOR': _CCLANEVENTUSERNEWSTUPLE,
    '__module__': 'steammessages_base_pb2'
    # @@protoc_insertion_point(class_scope:CClanEventUserNewsTuple)
})
_sym_db.RegisterMessage(CClanEventUserNewsTuple)

CClanMatchEventByRange = _reflection.GeneratedProtocolMessageType('CClanMatchEventByRange', (_message.Message,), {
    'DESCRIPTOR': _CCLANMATCHEVENTBYRANGE,
    '__module__': 'steammessages_base_pb2'
    # @@protoc_insertion_point(class_scope:CClanMatchEventByRange)
})
_sym_db.RegisterMessage(CClanMatchEventByRange)

CCommunity_ClanAnnouncementInfo = _reflection.GeneratedProtocolMessageType('CCommunity_ClanAnnouncementInfo', (_message.Message,), {
    'DESCRIPTOR': _CCOMMUNITY_CLANANNOUNCEMENTINFO,
    '__module__': 'steammessages_base_pb2'
    # @@protoc_insertion_point(class_scope:CCommunity_ClanAnnouncementInfo)
})
_sym_db.RegisterMessage(CCommunity_ClanAnnouncementInfo)

CClanEventData = _reflection.GeneratedProtocolMessageType('CClanEventData', (_message.Message,), {
    'DESCRIPTOR': _CCLANEVENTDATA,
    '__module__': 'steammessages_base_pb2'
    # @@protoc_insertion_point(class_scope:CClanEventData)
})
_sym_db.RegisterMessage(CClanEventData)

CBilling_Address = _reflection.GeneratedProtocolMessageType('CBilling_Address', (_message.Message,), {
    'DESCRIPTOR': _CBILLING_ADDRESS,
    '__module__': 'steammessages_base_pb2'
    # @@protoc_insertion_point(class_scope:CBilling_Address)
})
_sym_db.RegisterMessage(CBilling_Address)

CPackageReservationStatus = _reflection.GeneratedProtocolMessageType('CPackageReservationStatus', (_message.Message,), {
    'DESCRIPTOR': _CPACKAGERESERVATIONSTATUS,
    '__module__': 'steammessages_base_pb2'
    # @@protoc_insertion_point(class_scope:CPackageReservationStatus)
})
_sym_db.RegisterMessage(CPackageReservationStatus)

CMsgKeyValuePair = _reflection.GeneratedProtocolMessageType('CMsgKeyValuePair', (_message.Message,), {
    'DESCRIPTOR': _CMSGKEYVALUEPAIR,
    '__module__': 'steammessages_base_pb2'
    # @@protoc_insertion_point(class_scope:CMsgKeyValuePair)
})
_sym_db.RegisterMessage(CMsgKeyValuePair)

CMsgKeyValueSet = _reflection.GeneratedProtocolMessageType('CMsgKeyValueSet', (_message.Message,), {
    'DESCRIPTOR': _CMSGKEYVALUESET,
    '__module__': 'steammessages_base_pb2'
    # @@protoc_insertion_point(class_scope:CMsgKeyValueSet)
})
_sym_db.RegisterMessage(CMsgKeyValueSet)

if _descriptor._USE_C_DESCRIPTORS == False:
    google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(
        msgpool_soft_limit)
    google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(
        msgpool_hard_limit)
    google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(
        force_php_generation)
    google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(
        php_output_always_number)
    google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(
        allow_field_named_steam_id)

    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'H\001\200\001\001\200\265\030\001'
    _EBANCONTENTCHECKRESULT._serialized_start = 4451
    _EBANCONTENTCHECKRESULT._serialized_end = 4795
    _EPROTOCLANEVENTTYPE._serialized_start = 4798
    _EPROTOCLANEVENTTYPE._serialized_end = 5801
    _PARTNEREVENTNOTIFICATIONTYPE._serialized_start = 5804
    _PARTNEREVENTNOTIFICATIONTYPE._serialized_end = 5933
    _CMSGIPADDRESS._serialized_start = 62
    _CMSGIPADDRESS._serialized_end = 111
    _CMSGIPADDRESSBUCKET._serialized_start = 113
    _CMSGIPADDRESSBUCKET._serialized_end = 195
    _CMSGPROTOBUFHEADER._serialized_start = 198
    _CMSGPROTOBUFHEADER._serialized_end = 952
    _CMSGMULTI._serialized_start = 954
    _CMSGMULTI._serialized_end = 1010
    _CMSGPROTOBUFWRAPPED._serialized_start = 1012
    _CMSGPROTOBUFWRAPPED._serialized_end = 1055
    _CMSGAUTHTICKET._serialized_start = 1058
    _CMSGAUTHTICKET._serialized_end = 1201
    _CCDDBAPPDETAILCOMMON._serialized_start = 1204
    _CCDDBAPPDETAILCOMMON._serialized_end = 1469
    _CMSGAPPRIGHTS._serialized_start = 1472
    _CMSGAPPRIGHTS._serialized_end = 1907
    _CCURATORPREFERENCES._serialized_start = 1910
    _CCURATORPREFERENCES._serialized_end = 2279
    _CLOCALIZATIONTOKEN._serialized_start = 2281
    _CLOCALIZATIONTOKEN._serialized_end = 2345
    _CCLANEVENTUSERNEWSTUPLE._serialized_start = 2348
    _CCLANEVENTUSERNEWSTUPLE._serialized_end = 2584
    _CCLANMATCHEVENTBYRANGE._serialized_start = 2587
    _CCLANMATCHEVENTBYRANGE._serialized_end = 2715
    _CCOMMUNITY_CLANANNOUNCEMENTINFO._serialized_start = 2718
    _CCOMMUNITY_CLANANNOUNCEMENTINFO._serialized_end = 3113
    _CCLANEVENTDATA._serialized_start = 3116
    _CCLANEVENTDATA._serialized_end = 3922
    _CBILLING_ADDRESS._serialized_start = 3925
    _CBILLING_ADDRESS._serialized_end = 4124
    _CPACKAGERESERVATIONSTATUS._serialized_start = 4127
    _CPACKAGERESERVATIONSTATUS._serialized_end = 4346
    _CMSGKEYVALUEPAIR._serialized_start = 4348
    _CMSGKEYVALUEPAIR._serialized_end = 4395
    _CMSGKEYVALUESET._serialized_start = 4397
    _CMSGKEYVALUESET._serialized_end = 4448
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_unified_base.steamclient.proto
# flake8: noqa
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import enum_type_wrapper


# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,steammessages_unified_base.steamclient.proto\x1a google/protobuf/descriptor.proto\"\x0c\n\nNoResponse*]\n\x13\x45ProtoExecutionSite\x12 \n\x1ck_EProtoExecutionSiteUnknown\x10\x00\x12$\n k_EProtoExecutionSiteSteamClient\x10\x02:4\n\x0b\x64\x65scription\x12\x1d.google.protobuf.FieldOptions\x18\xd0\x86\x03 \x01(\t:>\n\x13service_description\x12\x1f.google.protobuf.ServiceOptions\x18\xd0\x86\x03 \x01(\t:u\n\x16service_execution_site\x12\x1f.google.protobuf.ServiceOptions\x18\xd8\x86\x03 \x01(\x0e\x32\x14.EProtoExecutionSite:\x1ck_EProtoExecutionSiteUnknown:<\n\x12method_description\x12\x1e.google.protobuf.MethodOptions\x18\xd0\x86\x03 \x01(\t:8\n\x10\x65num_description\x12\x1c.google.protobuf.EnumOptions\x18\xd0\x86\x03 \x01(\t:C\n\x16\x65num_value_description\x12!.google.protobuf.EnumValueOptions\x18\xd0\x86\x03 \x01(\tB\x05H\x01\x80\x01\x00')

_EPROTOEXECUTIONSITE = DESCRIPTOR.enum_types_by_name['EProtoExecutionSite']
EProtoExecutionSite = enum_type_wrapper.EnumTypeWrapper(_EPROTOEXECUTIONSITE)
k_EProtoExecutionSiteUnknown = 0
k_EProtoExecutionSiteSteamClient = 2

DESCRIPTION_FIELD_NUMBER = 50000
description = DESCRIPTOR.extensions_by_name['description']
SERVICE_DESCRIPTION_FIELD_NUMBER = 50000
service_description = DESCRIPTOR.extensions_by_name['service_description']
SERVICE_EXECUTION_SITE_FIELD_NUMBER = 50008
service_execution_site = DESCRIPTOR.extensions_by_name['service_execution_site']
METHOD_DESCRIPTION_FIELD_NUMBER = 50000
method_description = DESCRIPTOR.extensions_by_name['method_description']
ENUM_DESCRIPTION_FIELD_NUMBER = 50000
enum_description = DESCRIPTOR.extensions_by_name['enum_description']
ENUM_VALUE_DESCRIPTION_FIELD_NUMBER = 50000
enum_value_description = DESCRIPTOR.extensions_by_name['enum_value_description']

_NORESPONSE = DESCRIPTOR.message_types_by_name['NoResponse']
NoResponse = _reflection.GeneratedProtocolMessageType('NoResponse', (_message.Message,), {
    'DESCRIPTOR': _NORESPONSE,
    '__module__': 'steammessages_unified_base.steamclient_pb2'
    # @@protoc_insertion_point(class_scope:NoResponse)
})
_sym_db.RegisterMessage(NoResponse)

if _descriptor._USE_C_DESCRIPTORS == False:
    google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(
        description)
    google_dot_protobuf_dot_descriptor__pb2.ServiceOptions.RegisterExtension(
        service_description)
    google_dot_protobuf_dot_descriptor__pb2.ServiceOptions.RegisterExtension(
        service_execution_site)
    google_dot_protobuf_dot_descriptor__pb2.MethodOptions.RegisterExtension(
        method_description)
    google_dot_protobuf_dot_descriptor__pb2.EnumOptions.RegisterExtension(
        enum_description)
    google_dot_protobuf_dot_descriptor__pb2.EnumValueOptions.RegisterExtension(
        enum_value_description)

    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'H\001\200\001\000'
    _EPROTOEXECUTIONSITE._serialized_start = 96
    _EPROTOEXECUTIONSITE._serialized_end = 189
    _NORESPONSE._serialized_start = 82
    _NORESPONSE._serialized_end = 94
# @@protoc_insertion_point(module_scope)



from .codes import STEAM_ERROR_CODES
from .exceptions import (
    SteamError,
    TooManySteamRequestsError,
    UnauthorizedSteamRequestError,
    UnknownSteamError,
    custom_error_exception,
)
from .response import check_steam_error


__all__ = [
    'check_steam_error',
    'SteamError',
    'UnknownSteamError',
    'STEAM_ERROR_CODES',
    'custom_error_exception',
    'UnauthorizedSteamRequestError',
    'TooManySteamRequestsError',
]



from typing import (
    Any,
    Dict,
    Mapping,
    Optional,
    Type,
)

import aiohttp
from aiohttp import (
    ClientResponse,
    ClientSession,
)

from pysteamauth.abstract import RequestStrategyAbstract
from pysteamauth.errors import check_steam_error
from pysteamauth.errors.exceptions import (
    TooManySteamRequestsError,
    UnauthorizedSteamRequestError,
)


class BaseRequestStrategy(RequestStrategyAbstract):

    http_status_exception: Dict[int, Type[Exception]] = {
        401: UnauthorizedSteamRequestError,
        429: TooManySteamRequestsError,
    }

    def __init__(self):
        self._session: Optional[ClientSession] = None

    def __del__(self):
        if self._session:
            self._session.connector.close()

    def _create_session(self) -> ClientSession:
        """
        Create aiohttp session.
        Aiohttp session saves and stores cookies.
        It writes cookies from responses after each request that specified
        in Set-Cookie header.

        :return: aiohttp.ClientSession object.
        """
        return ClientSession(connector=aiohttp.TCPConnector(ssl=False))

    def _check_http_status(self, response: ClientResponse) -> None:
        status = response.status
        if not response.ok and status in self.http_status_exception:
            raise self.http_status_exception[status](
                f'Wrong HTTP status from Steam {status} url="{response.url}"',
            )

    async def request(self, url: str, method: str, **kwargs: Any) -> ClientResponse:
        if self._session is None:
            self._session = self._create_session()
        response = await self._session.request(method, url, **kwargs)
        error = response.headers.get('X-eresult')
        if error:
            check_steam_error(int(error))
        self._check_http_status(response)
        return response

    def cookies(self, domain: str = 'steamcommunity.com') -> Mapping[str, str]:
        if self._session is None:
            raise RuntimeError('Session is not initialized')
        cookies = {}
        for cookie in self._session.cookie_jar:
            if cookie['domain'] == domain:
                cookies[cookie.key] = cookie.value
        return cookies

    async def text(self, url: str, method: str, **kwargs: Any) -> str:
        return await (await self.request(url, method, **kwargs)).text()

    async def bytes(self, url: str, method: str, **kwargs: Any) -> bytes:
        return await (await self.request(url, method, **kwargs)).read()



from typing import (
    Dict,
    Mapping,
)

from pysteamauth.abstract import CookieStorageAbstract


class BaseCookieStorage(CookieStorageAbstract):

    def __init__(self):
        self.cookies: Dict[str, Mapping[str, Mapping[str, str]]] = {}

    async def set(self, login: str, cookies: Mapping[str, Mapping[str, str]]) -> None:
        self.cookies[login] = cookies

    async def get(self, login: str, domain: str = 'steamcommunity.com') -> Mapping[str, str]:
        cookies = self.cookies.get(login)
        if not cookies:
            return {}
        return cookies.get(domain, {})



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: enums.proto
# flake8: noqa
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message  # noqa
from google.protobuf import reflection as _reflection  # noqa
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import enum_type_wrapper

from . import steammessages_base_pb2 as steammessages__base__pb2  # noqa


# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()



DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x65nums.proto\x1a\x18steammessages_base.proto*\x80\n\n\x17\x45PublishedFileQueryType\x12)\n%k_PublishedFileQueryType_RankedByVote\x10\x00\x12\x34\n0k_PublishedFileQueryType_RankedByPublicationDate\x10\x01\x12\x42\n>k_PublishedFileQueryType_AcceptedForGameRankedByAcceptanceDate\x10\x02\x12*\n&k_PublishedFileQueryType_RankedByTrend\x10\x03\x12\x46\nBk_PublishedFileQueryType_FavoritedByFriendsRankedByPublicationDate\x10\x04\x12\x44\n@k_PublishedFileQueryType_CreatedByFriendsRankedByPublicationDate\x10\x05\x12\x35\n1k_PublishedFileQueryType_RankedByNumTimesReported\x10\x06\x12J\nFk_PublishedFileQueryType_CreatedByFollowedUsersRankedByPublicationDate\x10\x07\x12(\n$k_PublishedFileQueryType_NotYetRated\x10\x08\x12=\n9k_PublishedFileQueryType_RankedByTotalUniqueSubscriptions\x10\t\x12\x32\n.k_PublishedFileQueryType_RankedByTotalVotesAsc\x10\n\x12,\n(k_PublishedFileQueryType_RankedByVotesUp\x10\x0b\x12/\n+k_PublishedFileQueryType_RankedByTextSearch\x10\x0c\x12\x32\n.k_PublishedFileQueryType_RankedByPlaytimeTrend\x10\r\x12\x32\n.k_PublishedFileQueryType_RankedByTotalPlaytime\x10\x0e\x12\x39\n5k_PublishedFileQueryType_RankedByAveragePlaytimeTrend\x10\x0f\x12<\n8k_PublishedFileQueryType_RankedByLifetimeAveragePlaytime\x10\x10\x12:\n6k_PublishedFileQueryType_RankedByPlaytimeSessionsTrend\x10\x11\x12=\n9k_PublishedFileQueryType_RankedByLifetimePlaytimeSessions\x10\x12\x12?\n;k_PublishedFileQueryType_RankedByInappropriateContentRating\x10\x13\x12\x34\n0k_PublishedFileQueryType_RankedByBanContentCheck\x10\x14\x12\x34\n0k_PublishedFileQueryType_RankedByLastUpdatedDate\x10\x15*\xbc\x01\n#EPublishedFileInappropriateProvider\x12\x31\n-k_EPublishedFileInappropriateProvider_Invalid\x10\x00\x12\x30\n,k_EPublishedFileInappropriateProvider_Google\x10\x01\x12\x30\n,k_EPublishedFileInappropriateProvider_Amazon\x10\x02*\xd5\x02\n!EPublishedFileInappropriateResult\x12\x32\n.k_EPublishedFileInappropriateResult_NotScanned\x10\x00\x12\x34\n0k_EPublishedFileInappropriateResult_VeryUnlikely\x10\x01\x12\x30\n,k_EPublishedFileInappropriateResult_Unlikely\x10\x1e\x12\x30\n,k_EPublishedFileInappropriateResult_Possible\x10\x32\x12.\n*k_EPublishedFileInappropriateResult_Likely\x10K\x12\x32\n.k_EPublishedFileInappropriateResult_VeryLikely\x10\x64*\xb1\x03\n\x11\x45PersonaStateFlag\x12\'\n#k_EPersonaStateFlag_HasRichPresence\x10\x01\x12&\n\"k_EPersonaStateFlag_InJoinableGame\x10\x02\x12\x1e\n\x1ak_EPersonaStateFlag_Golden\x10\x04\x12*\n&k_EPersonaStateFlag_RemotePlayTogether\x10\x08\x12&\n!k_EPersonaStateFlag_ClientTypeWeb\x10\x80\x02\x12)\n$k_EPersonaStateFlag_ClientTypeMobile\x10\x80\x04\x12*\n%k_EPersonaStateFlag_ClientTypeTenfoot\x10\x80\x08\x12%\n k_EPersonaStateFlag_ClientTypeVR\x10\x80\x10\x12*\n%k_EPersonaStateFlag_LaunchTypeGamepad\x10\x80 \x12-\n(k_EPersonaStateFlag_LaunchTypeCompatTool\x10\x80@*\xa7\x01\n\x15\x45\x43ontentCheckProvider\x12#\n\x1fk_EContentCheckProvider_Invalid\x10\x00\x12\"\n\x1ek_EContentCheckProvider_Google\x10\x01\x12\"\n\x1ek_EContentCheckProvider_Amazon\x10\x02\x12!\n\x1dk_EContentCheckProvider_Local\x10\x03*\xec\x08\n\x19\x45ProfileCustomizationType\x12&\n\"k_EProfileCustomizationTypeInvalid\x10\x00\x12\x36\n2k_EProfileCustomizationTypeRareAchievementShowcase\x10\x01\x12,\n(k_EProfileCustomizationTypeGameCollector\x10\x02\x12+\n\'k_EProfileCustomizationTypeItemShowcase\x10\x03\x12,\n(k_EProfileCustomizationTypeTradeShowcase\x10\x04\x12%\n!k_EProfileCustomizationTypeBadges\x10\x05\x12+\n\'k_EProfileCustomizationTypeFavoriteGame\x10\x06\x12\x31\n-k_EProfileCustomizationTypeScreenshotShowcase\x10\x07\x12)\n%k_EProfileCustomizationTypeCustomText\x10\x08\x12,\n(k_EProfileCustomizationTypeFavoriteGroup\x10\t\x12-\n)k_EProfileCustomizationTypeRecommendation\x10\n\x12+\n\'k_EProfileCustomizationTypeWorkshopItem\x10\x0b\x12)\n%k_EProfileCustomizationTypeMyWorkshop\x10\x0c\x12.\n*k_EProfileCustomizationTypeArtworkShowcase\x10\r\x12,\n(k_EProfileCustomizationTypeVideoShowcase\x10\x0e\x12%\n!k_EProfileCustomizationTypeGuides\x10\x0f\x12\'\n#k_EProfileCustomizationTypeMyGuides\x10\x10\x12+\n\'k_EProfileCustomizationTypeAchievements\x10\x11\x12)\n%k_EProfileCustomizationTypeGreenlight\x10\x12\x12+\n\'k_EProfileCustomizationTypeMyGreenlight\x10\x13\x12%\n!k_EProfileCustomizationTypeSalien\x10\x14\x12\x35\n1k_EProfileCustomizationTypeLoyaltyRewardReactions\x10\x15\x12\x34\n0k_EProfileCustomizationTypeSingleArtworkShowcase\x10\x16\x12\x38\n4k_EProfileCustomizationTypeAchievementsCompletionist\x10\x17*\xc8\x01\n\x1b\x45PublishedFileStorageSystem\x12(\n$k_EPublishedFileStorageSystemInvalid\x10\x00\x12,\n(k_EPublishedFileStorageSystemLegacyCloud\x10\x01\x12&\n\"k_EPublishedFileStorageSystemDepot\x10\x02\x12)\n%k_EPublishedFileStorageSystemUGCCloud\x10\x03*\x97\x01\n\x19\x45\x43loudStoragePersistState\x12(\n$k_ECloudStoragePersistStatePersisted\x10\x00\x12(\n$k_ECloudStoragePersistStateForgotten\x10\x01\x12&\n\"k_ECloudStoragePersistStateDeleted\x10\x02*\xe8\x01\n\x12\x45SDCardFormatStage\x12 \n\x1ck_ESDCardFormatStage_Invalid\x10\x00\x12!\n\x1dk_ESDCardFormatStage_Starting\x10\x01\x12 \n\x1ck_ESDCardFormatStage_Testing\x10\x02\x12!\n\x1dk_ESDCardFormatStage_Rescuing\x10\x03\x12#\n\x1fk_ESDCardFormatStage_Formatting\x10\x04\x12#\n\x1fk_ESDCardFormatStage_Finalizing\x10\x05*\x84\x01\n\x15\x45SystemFanControlMode\x12\"\n\x1ek_SystemFanControlMode_Invalid\x10\x00\x12#\n\x1fk_SystemFanControlMode_Disabled\x10\x01\x12\"\n\x1ek_SystemFanControlMode_Default\x10\x02*\x81\x01\n\rEColorProfile\x12\x1b\n\x17k_EColorProfile_Invalid\x10\x00\x12\x1a\n\x16k_EColorProfile_Native\x10\x01\x12\x1c\n\x18k_EColorProfile_Standard\x10\x02\x12\x19\n\x15k_EColorProfile_Vivid\x10\x03*\xc0\x03\n\x14\x45\x42luetoothDeviceType\x12!\n\x1dk_BluetoothDeviceType_Invalid\x10\x00\x12!\n\x1dk_BluetoothDeviceType_Unknown\x10\x01\x12\x1f\n\x1bk_BluetoothDeviceType_Phone\x10\x02\x12\"\n\x1ek_BluetoothDeviceType_Computer\x10\x03\x12!\n\x1dk_BluetoothDeviceType_Headset\x10\x04\x12$\n k_BluetoothDeviceType_Headphones\x10\x05\x12\"\n\x1ek_BluetoothDeviceType_Speakers\x10\x06\x12$\n k_BluetoothDeviceType_OtherAudio\x10\x07\x12\x1f\n\x1bk_BluetoothDeviceType_Mouse\x10\x08\x12\"\n\x1ek_BluetoothDeviceType_Joystick\x10\t\x12!\n\x1dk_BluetoothDeviceType_Gamepad\x10\n\x12\"\n\x1ek_BluetoothDeviceType_Keyboard\x10\x0b*\x80\x01\n\x15\x45SystemAudioDirection\x12\"\n\x1ek_SystemAudioDirection_Invalid\x10\x00\x12 \n\x1ck_SystemAudioDirection_Input\x10\x01\x12!\n\x1dk_SystemAudioDirection_Output\x10\x02*\xf1\x02\n\x13\x45SystemAudioChannel\x12 \n\x1ck_SystemAudioChannel_Invalid\x10\x00\x12#\n\x1fk_SystemAudioChannel_Aggregated\x10\x01\x12\"\n\x1ek_SystemAudioChannel_FrontLeft\x10\x02\x12#\n\x1fk_SystemAudioChannel_FrontRight\x10\x03\x12\x1c\n\x18k_SystemAudioChannel_LFE\x10\x04\x12!\n\x1dk_SystemAudioChannel_BackLeft\x10\x05\x12\"\n\x1ek_SystemAudioChannel_BackRight\x10\x06\x12$\n k_SystemAudioChannel_FrontCenter\x10\x07\x12 \n\x1ck_SystemAudioChannel_Unknown\x10\x08\x12\x1d\n\x19k_SystemAudioChannel_Mono\x10\t*\xc9\x01\n\x14\x45SystemAudioPortType\x12!\n\x1dk_SystemAudioPortType_Invalid\x10\x00\x12!\n\x1dk_SystemAudioPortType_Unknown\x10\x01\x12\"\n\x1ek_SystemAudioPortType_Audio32f\x10\x02\x12 \n\x1ck_SystemAudioPortType_Midi8b\x10\x03\x12%\n!k_SystemAudioPortType_Video32RGBA\x10\x04*\x90\x01\n\x19\x45SystemAudioPortDirection\x12&\n\"k_SystemAudioPortDirection_Invalid\x10\x00\x12$\n k_SystemAudioPortDirection_Input\x10\x01\x12%\n!k_SystemAudioPortDirection_Output\x10\x02*\x83\x01\n\x13\x45SystemServiceState\x12%\n!k_ESystemServiceState_Unavailable\x10\x00\x12\"\n\x1ek_ESystemServiceState_Disabled\x10\x01\x12!\n\x1dk_ESystemServiceState_Enabled\x10\x02*\xe1\x01\n\x19\x45GraphicsPerfOverlayLevel\x12&\n\"k_EGraphicsPerfOverlayLevel_Hidden\x10\x00\x12%\n!k_EGraphicsPerfOverlayLevel_Basic\x10\x01\x12&\n\"k_EGraphicsPerfOverlayLevel_Medium\x10\x02\x12$\n k_EGraphicsPerfOverlayLevel_Full\x10\x03\x12\'\n#k_EGraphicsPerfOverlayLevel_Minimal\x10\x04*\xe5\x01\n\x14\x45GPUPerformanceLevel\x12\"\n\x1ek_EGPUPerformanceLevel_Invalid\x10\x00\x12\x1f\n\x1bk_EGPUPerformanceLevel_Auto\x10\x01\x12!\n\x1dk_EGPUPerformanceLevel_Manual\x10\x02\x12\x1e\n\x1ak_EGPUPerformanceLevel_Low\x10\x03\x12\x1f\n\x1bk_EGPUPerformanceLevel_High\x10\x04\x12$\n k_EGPUPerformanceLevel_Profiling\x10\x05*\xbb\x01\n\x0e\x45ScalingFilter\x12\x1c\n\x18k_EScalingFilter_Invalid\x10\x00\x12\x18\n\x14k_EScalingFilter_FSR\x10\x01\x12\x1c\n\x18k_EScalingFilter_Nearest\x10\x02\x12\x1c\n\x18k_EScalingFilter_Integer\x10\x03\x12\x1b\n\x17k_EScalingFilter_Linear\x10\x04\x12\x18\n\x14k_EScalingFilter_NIS\x10\x05*|\n\x0c\x45\x43PUGovernor\x12\x1a\n\x16k_ECPUGovernor_Invalid\x10\x00\x12\x17\n\x13k_ECPUGovernor_Perf\x10\x01\x12\x1c\n\x18k_ECPUGovernor_Powersave\x10\x02\x12\x19\n\x15k_ECPUGovernor_Manual\x10\x03*\xe2\x01\n\x0c\x45UpdaterType\x12\x1a\n\x16k_EUpdaterType_Invalid\x10\x00\x12\x19\n\x15k_EUpdaterType_Client\x10\x01\x12\x15\n\x11k_EUpdaterType_OS\x10\x02\x12\x17\n\x13k_EUpdaterType_BIOS\x10\x03\x12\x1d\n\x19k_EUpdaterType_Aggregated\x10\x04\x12\x18\n\x14k_EUpdaterType_Test1\x10\x05\x12\x18\n\x14k_EUpdaterType_Test2\x10\x06\x12\x18\n\x14k_EUpdaterType_Dummy\x10\x07*\xf9\x01\n\rEUpdaterState\x12\x1b\n\x17k_EUpdaterState_Invalid\x10\x00\x12\x1c\n\x18k_EUpdaterState_UpToDate\x10\x02\x12\x1c\n\x18k_EUpdaterState_Checking\x10\x03\x12\x1d\n\x19k_EUpdaterState_Available\x10\x04\x12\x1c\n\x18k_EUpdaterState_Applying\x10\x05\x12(\n$k_EUpdaterState_ClientRestartPending\x10\x06\x12(\n$k_EUpdaterState_SystemRestartPending\x10\x07*\xe1\x01\n\x18\x45StorageBlockContentType\x12&\n\"k_EStorageBlockContentType_Invalid\x10\x00\x12&\n\"k_EStorageBlockContentType_Unknown\x10\x01\x12)\n%k_EStorageBlockContentType_FileSystem\x10\x02\x12%\n!k_EStorageBlockContentType_Crypto\x10\x03\x12#\n\x1fk_EStorageBlockContentType_Raid\x10\x04*\xc3\x01\n\x1b\x45StorageBlockFileSystemType\x12)\n%k_EStorageBlockFileSystemType_Invalid\x10\x00\x12)\n%k_EStorageBlockFileSystemType_Unknown\x10\x01\x12&\n\"k_EStorageBlockFileSystemType_VFat\x10\x02\x12&\n\"k_EStorageBlockFileSystemType_Ext4\x10\x03*\xe3\x01\n\x1f\x45SteamDeckCompatibilityCategory\x12-\n)k_ESteamDeckCompatibilityCategory_Unknown\x10\x00\x12\x31\n-k_ESteamDeckCompatibilityCategory_Unsupported\x10\x01\x12.\n*k_ESteamDeckCompatibilityCategory_Playable\x10\x02\x12.\n*k_ESteamDeckCompatibilityCategory_Verified\x10\x03*\xd0\x02\n(ESteamDeckCompatibilityResultDisplayType\x12\x38\n4k_ESteamDeckCompatibilityResultDisplayType_Invisible\x10\x00\x12<\n8k_ESteamDeckCompatibilityResultDisplayType_Informational\x10\x01\x12:\n6k_ESteamDeckCompatibilityResultDisplayType_Unsupported\x10\x02\x12\x37\n3k_ESteamDeckCompatibilityResultDisplayType_Playable\x10\x03\x12\x37\n3k_ESteamDeckCompatibilityResultDisplayType_Verified\x10\x04*w\n\x08\x45\x41\x43State\x12\x16\n\x12k_EACState_Unknown\x10\x00\x12\x1b\n\x17k_EACState_Disconnected\x10\x01\x12\x18\n\x14k_EACState_Connected\x10\x02\x12\x1c\n\x18k_EACState_ConnectedSlow\x10\x03*\x85\x01\n\rEBatteryState\x12\x1b\n\x17k_EBatteryState_Unknown\x10\x00\x12\x1f\n\x1bk_EBatteryState_Discharging\x10\x01\x12\x1c\n\x18k_EBatteryState_Charging\x10\x02\x12\x18\n\x14k_EBatteryState_Full\x10\x03*\xaa\x01\n\tEOSBranch\x12\x17\n\x13k_EOSBranch_Unknown\x10\x00\x12\x17\n\x13k_EOSBranch_Release\x10\x01\x12 \n\x1ck_EOSBranch_ReleaseCandidate\x10\x02\x12\x14\n\x10k_EOSBranch_Beta\x10\x03\x12\x1d\n\x19k_EOSBranch_BetaCandidate\x10\x04\x12\x14\n\x10k_EOSBranch_Main\x10\x05*\xac\x05\n\x13\x45\x43ommunityItemClass\x12!\n\x1dk_ECommunityItemClass_Invalid\x10\x00\x12\x1f\n\x1bk_ECommunityItemClass_Badge\x10\x01\x12\"\n\x1ek_ECommunityItemClass_GameCard\x10\x02\x12+\n\'k_ECommunityItemClass_ProfileBackground\x10\x03\x12\"\n\x1ek_ECommunityItemClass_Emoticon\x10\x04\x12%\n!k_ECommunityItemClass_BoosterPack\x10\x05\x12$\n k_ECommunityItemClass_Consumable\x10\x06\x12!\n\x1dk_ECommunityItemClass_GameGoo\x10\x07\x12)\n%k_ECommunityItemClass_ProfileModifier\x10\x08\x12\x1f\n\x1bk_ECommunityItemClass_Scene\x10\t\x12$\n k_ECommunityItemClass_SalienItem\x10\n\x12!\n\x1dk_ECommunityItemClass_Sticker\x10\x0b\x12$\n k_ECommunityItemClass_ChatEffect\x10\x0c\x12/\n+k_ECommunityItemClass_MiniProfileBackground\x10\r\x12%\n!k_ECommunityItemClass_AvatarFrame\x10\x0e\x12(\n$k_ECommunityItemClass_AnimatedAvatar\x10\x0f\x12/\n+k_ECommunityItemClass_SteamDeckKeyboardSkin\x10\x10*\xd9\x01\n\x1f\x45SteamDeckCompatibilityFeedback\x12+\n\'k_ESteamDeckCompatibilityFeedback_Unset\x10\x00\x12+\n\'k_ESteamDeckCompatibilityFeedback_Agree\x10\x01\x12.\n*k_ESteamDeckCompatibilityFeedback_Disagree\x10\x02\x12,\n(k_ESteamDeckCompatibilityFeedback_Ignore\x10\x03*\x9f\x01\n\x1e\x45ProvideDeckFeedbackPreference\x12*\n&k_EProvideDeckFeedbackPreference_Unset\x10\x00\x12(\n$k_EProvideDeckFeedbackPreference_Yes\x10\x01\x12\'\n#k_EProvideDeckFeedbackPreference_No\x10\x02*\xb1\x03\n\rETouchGesture\x12\x17\n\x13k_ETouchGestureNone\x10\x00\x12\x18\n\x14k_ETouchGestureTouch\x10\x01\x12\x16\n\x12k_ETouchGestureTap\x10\x02\x12\x1c\n\x18k_ETouchGestureDoubleTap\x10\x03\x12\x1d\n\x19k_ETouchGestureShortPress\x10\x04\x12\x1c\n\x18k_ETouchGestureLongPress\x10\x05\x12\x1a\n\x16k_ETouchGestureLongTap\x10\x06\x12\x1f\n\x1bk_ETouchGestureTwoFingerTap\x10\x07\x12\x1f\n\x1bk_ETouchGestureTapCancelled\x10\x08\x12\x1d\n\x19k_ETouchGesturePinchBegin\x10\t\x12\x1e\n\x1ak_ETouchGesturePinchUpdate\x10\n\x12\x1b\n\x17k_ETouchGesturePinchEnd\x10\x0b\x12\x1d\n\x19k_ETouchGestureFlingStart\x10\x0c\x12!\n\x1dk_ETouchGestureFlingCancelled\x10\r*\x8c\x01\n\x13\x45SessionPersistence\x12*\n\x1dk_ESessionPersistence_Invalid\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12#\n\x1fk_ESessionPersistence_Ephemeral\x10\x00\x12$\n k_ESessionPersistence_Persistent\x10\x01\x42\tH\x01\x80\x01\x01\x80\xb5\x18\x01')

_EPUBLISHEDFILEQUERYTYPE = DESCRIPTOR.enum_types_by_name['EPublishedFileQueryType']
EPublishedFileQueryType = enum_type_wrapper.EnumTypeWrapper(
    _EPUBLISHEDFILEQUERYTYPE)
_EPUBLISHEDFILEINAPPROPRIATEPROVIDER = DESCRIPTOR.enum_types_by_name[
    'EPublishedFileInappropriateProvider']
EPublishedFileInappropriateProvider = enum_type_wrapper.EnumTypeWrapper(
    _EPUBLISHEDFILEINAPPROPRIATEPROVIDER)
_EPUBLISHEDFILEINAPPROPRIATERESULT = DESCRIPTOR.enum_types_by_name[
    'EPublishedFileInappropriateResult']
EPublishedFileInappropriateResult = enum_type_wrapper.EnumTypeWrapper(
    _EPUBLISHEDFILEINAPPROPRIATERESULT)
_EPERSONASTATEFLAG = DESCRIPTOR.enum_types_by_name['EPersonaStateFlag']
EPersonaStateFlag = enum_type_wrapper.EnumTypeWrapper(_EPERSONASTATEFLAG)
_ECONTENTCHECKPROVIDER = DESCRIPTOR.enum_types_by_name['EContentCheckProvider']
EContentCheckProvider = enum_type_wrapper.EnumTypeWrapper(
    _ECONTENTCHECKPROVIDER)
_EPROFILECUSTOMIZATIONTYPE = DESCRIPTOR.enum_types_by_name['EProfileCustomizationType']
EProfileCustomizationType = enum_type_wrapper.EnumTypeWrapper(
    _EPROFILECUSTOMIZATIONTYPE)
_EPUBLISHEDFILESTORAGESYSTEM = DESCRIPTOR.enum_types_by_name['EPublishedFileStorageSystem']
EPublishedFileStorageSystem = enum_type_wrapper.EnumTypeWrapper(
    _EPUBLISHEDFILESTORAGESYSTEM)
_ECLOUDSTORAGEPERSISTSTATE = DESCRIPTOR.enum_types_by_name['ECloudStoragePersistState']
ECloudStoragePersistState = enum_type_wrapper.EnumTypeWrapper(
    _ECLOUDSTORAGEPERSISTSTATE)
_ESDCARDFORMATSTAGE = DESCRIPTOR.enum_types_by_name['ESDCardFormatStage']
ESDCardFormatStage = enum_type_wrapper.EnumTypeWrapper(_ESDCARDFORMATSTAGE)
_ESYSTEMFANCONTROLMODE = DESCRIPTOR.enum_types_by_name['ESystemFanControlMode']
ESystemFanControlMode = enum_type_wrapper.EnumTypeWrapper(
    _ESYSTEMFANCONTROLMODE)
_ECOLORPROFILE = DESCRIPTOR.enum_types_by_name['EColorProfile']
EColorProfile = enum_type_wrapper.EnumTypeWrapper(_ECOLORPROFILE)
_EBLUETOOTHDEVICETYPE = DESCRIPTOR.enum_types_by_name['EBluetoothDeviceType']
EBluetoothDeviceType = enum_type_wrapper.EnumTypeWrapper(_EBLUETOOTHDEVICETYPE)
_ESYSTEMAUDIODIRECTION = DESCRIPTOR.enum_types_by_name['ESystemAudioDirection']
ESystemAudioDirection = enum_type_wrapper.EnumTypeWrapper(
    _ESYSTEMAUDIODIRECTION)
_ESYSTEMAUDIOCHANNEL = DESCRIPTOR.enum_types_by_name['ESystemAudioChannel']
ESystemAudioChannel = enum_type_wrapper.EnumTypeWrapper(_ESYSTEMAUDIOCHANNEL)
_ESYSTEMAUDIOPORTTYPE = DESCRIPTOR.enum_types_by_name['ESystemAudioPortType']
ESystemAudioPortType = enum_type_wrapper.EnumTypeWrapper(_ESYSTEMAUDIOPORTTYPE)
_ESYSTEMAUDIOPORTDIRECTION = DESCRIPTOR.enum_types_by_name['ESystemAudioPortDirection']
ESystemAudioPortDirection = enum_type_wrapper.EnumTypeWrapper(
    _ESYSTEMAUDIOPORTDIRECTION)
_ESYSTEMSERVICESTATE = DESCRIPTOR.enum_types_by_name['ESystemServiceState']
ESystemServiceState = enum_type_wrapper.EnumTypeWrapper(_ESYSTEMSERVICESTATE)
_EGRAPHICSPERFOVERLAYLEVEL = DESCRIPTOR.enum_types_by_name['EGraphicsPerfOverlayLevel']
EGraphicsPerfOverlayLevel = enum_type_wrapper.EnumTypeWrapper(
    _EGRAPHICSPERFOVERLAYLEVEL)
_EGPUPERFORMANCELEVEL = DESCRIPTOR.enum_types_by_name['EGPUPerformanceLevel']
EGPUPerformanceLevel = enum_type_wrapper.EnumTypeWrapper(_EGPUPERFORMANCELEVEL)
_ESCALINGFILTER = DESCRIPTOR.enum_types_by_name['EScalingFilter']
EScalingFilter = enum_type_wrapper.EnumTypeWrapper(_ESCALINGFILTER)
_ECPUGOVERNOR = DESCRIPTOR.enum_types_by_name['ECPUGovernor']
ECPUGovernor = enum_type_wrapper.EnumTypeWrapper(_ECPUGOVERNOR)
_EUPDATERTYPE = DESCRIPTOR.enum_types_by_name['EUpdaterType']
EUpdaterType = enum_type_wrapper.EnumTypeWrapper(_EUPDATERTYPE)
_EUPDATERSTATE = DESCRIPTOR.enum_types_by_name['EUpdaterState']
EUpdaterState = enum_type_wrapper.EnumTypeWrapper(_EUPDATERSTATE)
_ESTORAGEBLOCKCONTENTTYPE = DESCRIPTOR.enum_types_by_name['EStorageBlockContentType']
EStorageBlockContentType = enum_type_wrapper.EnumTypeWrapper(
    _ESTORAGEBLOCKCONTENTTYPE)
_ESTORAGEBLOCKFILESYSTEMTYPE = DESCRIPTOR.enum_types_by_name['EStorageBlockFileSystemType']
EStorageBlockFileSystemType = enum_type_wrapper.EnumTypeWrapper(
    _ESTORAGEBLOCKFILESYSTEMTYPE)
_ESTEAMDECKCOMPATIBILITYCATEGORY = DESCRIPTOR.enum_types_by_name[
    'ESteamDeckCompatibilityCategory']
ESteamDeckCompatibilityCategory = enum_type_wrapper.EnumTypeWrapper(
    _ESTEAMDECKCOMPATIBILITYCATEGORY)
_ESTEAMDECKCOMPATIBILITYRESULTDISPLAYTYPE = DESCRIPTOR.enum_types_by_name[
    'ESteamDeckCompatibilityResultDisplayType']
ESteamDeckCompatibilityResultDisplayType = enum_type_wrapper.EnumTypeWrapper(
    _ESTEAMDECKCOMPATIBILITYRESULTDISPLAYTYPE)
_EACSTATE = DESCRIPTOR.enum_types_by_name['EACState']
EACState = enum_type_wrapper.EnumTypeWrapper(_EACSTATE)
_EBATTERYSTATE = DESCRIPTOR.enum_types_by_name['EBatteryState']
EBatteryState = enum_type_wrapper.EnumTypeWrapper(_EBATTERYSTATE)
_EOSBRANCH = DESCRIPTOR.enum_types_by_name['EOSBranch']
EOSBranch = enum_type_wrapper.EnumTypeWrapper(_EOSBRANCH)
_ECOMMUNITYITEMCLASS = DESCRIPTOR.enum_types_by_name['ECommunityItemClass']
ECommunityItemClass = enum_type_wrapper.EnumTypeWrapper(_ECOMMUNITYITEMCLASS)
_ESTEAMDECKCOMPATIBILITYFEEDBACK = DESCRIPTOR.enum_types_by_name[
    'ESteamDeckCompatibilityFeedback']
ESteamDeckCompatibilityFeedback = enum_type_wrapper.EnumTypeWrapper(
    _ESTEAMDECKCOMPATIBILITYFEEDBACK)
_EPROVIDEDECKFEEDBACKPREFERENCE = DESCRIPTOR.enum_types_by_name[
    'EProvideDeckFeedbackPreference']
EProvideDeckFeedbackPreference = enum_type_wrapper.EnumTypeWrapper(
    _EPROVIDEDECKFEEDBACKPREFERENCE)
_ETOUCHGESTURE = DESCRIPTOR.enum_types_by_name['ETouchGesture']
ETouchGesture = enum_type_wrapper.EnumTypeWrapper(_ETOUCHGESTURE)
_ESESSIONPERSISTENCE = DESCRIPTOR.enum_types_by_name['ESessionPersistence']
ESessionPersistence = enum_type_wrapper.EnumTypeWrapper(_ESESSIONPERSISTENCE)
k_PublishedFileQueryType_RankedByVote = 0
k_PublishedFileQueryType_RankedByPublicationDate = 1
k_PublishedFileQueryType_AcceptedForGameRankedByAcceptanceDate = 2
k_PublishedFileQueryType_RankedByTrend = 3
k_PublishedFileQueryType_FavoritedByFriendsRankedByPublicationDate = 4
k_PublishedFileQueryType_CreatedByFriendsRankedByPublicationDate = 5
k_PublishedFileQueryType_RankedByNumTimesReported = 6
k_PublishedFileQueryType_CreatedByFollowedUsersRankedByPublicationDate = 7
k_PublishedFileQueryType_NotYetRated = 8
k_PublishedFileQueryType_RankedByTotalUniqueSubscriptions = 9
k_PublishedFileQueryType_RankedByTotalVotesAsc = 10
k_PublishedFileQueryType_RankedByVotesUp = 11
k_PublishedFileQueryType_RankedByTextSearch = 12
k_PublishedFileQueryType_RankedByPlaytimeTrend = 13
k_PublishedFileQueryType_RankedByTotalPlaytime = 14
k_PublishedFileQueryType_RankedByAveragePlaytimeTrend = 15
k_PublishedFileQueryType_RankedByLifetimeAveragePlaytime = 16
k_PublishedFileQueryType_RankedByPlaytimeSessionsTrend = 17
k_PublishedFileQueryType_RankedByLifetimePlaytimeSessions = 18
k_PublishedFileQueryType_RankedByInappropriateContentRating = 19
k_PublishedFileQueryType_RankedByBanContentCheck = 20
k_PublishedFileQueryType_RankedByLastUpdatedDate = 21
k_EPublishedFileInappropriateProvider_Invalid = 0
k_EPublishedFileInappropriateProvider_Google = 1
k_EPublishedFileInappropriateProvider_Amazon = 2
k_EPublishedFileInappropriateResult_NotScanned = 0
k_EPublishedFileInappropriateResult_VeryUnlikely = 1
k_EPublishedFileInappropriateResult_Unlikely = 30
k_EPublishedFileInappropriateResult_Possible = 50
k_EPublishedFileInappropriateResult_Likely = 75
k_EPublishedFileInappropriateResult_VeryLikely = 100
k_EPersonaStateFlag_HasRichPresence = 1
k_EPersonaStateFlag_InJoinableGame = 2
k_EPersonaStateFlag_Golden = 4
k_EPersonaStateFlag_RemotePlayTogether = 8
k_EPersonaStateFlag_ClientTypeWeb = 256
k_EPersonaStateFlag_ClientTypeMobile = 512
k_EPersonaStateFlag_ClientTypeTenfoot = 1024
k_EPersonaStateFlag_ClientTypeVR = 2048
k_EPersonaStateFlag_LaunchTypeGamepad = 4096
k_EPersonaStateFlag_LaunchTypeCompatTool = 8192
k_EContentCheckProvider_Invalid = 0
k_EContentCheckProvider_Google = 1
k_EContentCheckProvider_Amazon = 2
k_EContentCheckProvider_Local = 3
k_EProfileCustomizationTypeInvalid = 0
k_EProfileCustomizationTypeRareAchievementShowcase = 1
k_EProfileCustomizationTypeGameCollector = 2
k_EProfileCustomizationTypeItemShowcase = 3
k_EProfileCustomizationTypeTradeShowcase = 4
k_EProfileCustomizationTypeBadges = 5
k_EProfileCustomizationTypeFavoriteGame = 6
k_EProfileCustomizationTypeScreenshotShowcase = 7
k_EProfileCustomizationTypeCustomText = 8
k_EProfileCustomizationTypeFavoriteGroup = 9
k_EProfileCustomizationTypeRecommendation = 10
k_EProfileCustomizationTypeWorkshopItem = 11
k_EProfileCustomizationTypeMyWorkshop = 12
k_EProfileCustomizationTypeArtworkShowcase = 13
k_EProfileCustomizationTypeVideoShowcase = 14
k_EProfileCustomizationTypeGuides = 15
k_EProfileCustomizationTypeMyGuides = 16
k_EProfileCustomizationTypeAchievements = 17
k_EProfileCustomizationTypeGreenlight = 18
k_EProfileCustomizationTypeMyGreenlight = 19
k_EProfileCustomizationTypeSalien = 20
k_EProfileCustomizationTypeLoyaltyRewardReactions = 21
k_EProfileCustomizationTypeSingleArtworkShowcase = 22
k_EProfileCustomizationTypeAchievementsCompletionist = 23
k_EPublishedFileStorageSystemInvalid = 0
k_EPublishedFileStorageSystemLegacyCloud = 1
k_EPublishedFileStorageSystemDepot = 2
k_EPublishedFileStorageSystemUGCCloud = 3
k_ECloudStoragePersistStatePersisted = 0
k_ECloudStoragePersistStateForgotten = 1
k_ECloudStoragePersistStateDeleted = 2
k_ESDCardFormatStage_Invalid = 0
k_ESDCardFormatStage_Starting = 1
k_ESDCardFormatStage_Testing = 2
k_ESDCardFormatStage_Rescuing = 3
k_ESDCardFormatStage_Formatting = 4
k_ESDCardFormatStage_Finalizing = 5
k_SystemFanControlMode_Invalid = 0
k_SystemFanControlMode_Disabled = 1
k_SystemFanControlMode_Default = 2
k_EColorProfile_Invalid = 0
k_EColorProfile_Native = 1
k_EColorProfile_Standard = 2
k_EColorProfile_Vivid = 3
k_BluetoothDeviceType_Invalid = 0
k_BluetoothDeviceType_Unknown = 1
k_BluetoothDeviceType_Phone = 2
k_BluetoothDeviceType_Computer = 3
k_BluetoothDeviceType_Headset = 4
k_BluetoothDeviceType_Headphones = 5
k_BluetoothDeviceType_Speakers = 6
k_BluetoothDeviceType_OtherAudio = 7
k_BluetoothDeviceType_Mouse = 8
k_BluetoothDeviceType_Joystick = 9
k_BluetoothDeviceType_Gamepad = 10
k_BluetoothDeviceType_Keyboard = 11
k_SystemAudioDirection_Invalid = 0
k_SystemAudioDirection_Input = 1
k_SystemAudioDirection_Output = 2
k_SystemAudioChannel_Invalid = 0
k_SystemAudioChannel_Aggregated = 1
k_SystemAudioChannel_FrontLeft = 2
k_SystemAudioChannel_FrontRight = 3
k_SystemAudioChannel_LFE = 4
k_SystemAudioChannel_BackLeft = 5
k_SystemAudioChannel_BackRight = 6
k_SystemAudioChannel_FrontCenter = 7
k_SystemAudioChannel_Unknown = 8
k_SystemAudioChannel_Mono = 9
k_SystemAudioPortType_Invalid = 0
k_SystemAudioPortType_Unknown = 1
k_SystemAudioPortType_Audio32f = 2
k_SystemAudioPortType_Midi8b = 3
k_SystemAudioPortType_Video32RGBA = 4
k_SystemAudioPortDirection_Invalid = 0
k_SystemAudioPortDirection_Input = 1
k_SystemAudioPortDirection_Output = 2
k_ESystemServiceState_Unavailable = 0
k_ESystemServiceState_Disabled = 1
k_ESystemServiceState_Enabled = 2
k_EGraphicsPerfOverlayLevel_Hidden = 0
k_EGraphicsPerfOverlayLevel_Basic = 1
k_EGraphicsPerfOverlayLevel_Medium = 2
k_EGraphicsPerfOverlayLevel_Full = 3
k_EGraphicsPerfOverlayLevel_Minimal = 4
k_EGPUPerformanceLevel_Invalid = 0
k_EGPUPerformanceLevel_Auto = 1
k_EGPUPerformanceLevel_Manual = 2
k_EGPUPerformanceLevel_Low = 3
k_EGPUPerformanceLevel_High = 4
k_EGPUPerformanceLevel_Profiling = 5
k_EScalingFilter_Invalid = 0
k_EScalingFilter_FSR = 1
k_EScalingFilter_Nearest = 2
k_EScalingFilter_Integer = 3
k_EScalingFilter_Linear = 4
k_EScalingFilter_NIS = 5
k_ECPUGovernor_Invalid = 0
k_ECPUGovernor_Perf = 1
k_ECPUGovernor_Powersave = 2
k_ECPUGovernor_Manual = 3
k_EUpdaterType_Invalid = 0
k_EUpdaterType_Client = 1
k_EUpdaterType_OS = 2
k_EUpdaterType_BIOS = 3
k_EUpdaterType_Aggregated = 4
k_EUpdaterType_Test1 = 5
k_EUpdaterType_Test2 = 6
k_EUpdaterType_Dummy = 7
k_EUpdaterState_Invalid = 0
k_EUpdaterState_UpToDate = 2
k_EUpdaterState_Checking = 3
k_EUpdaterState_Available = 4
k_EUpdaterState_Applying = 5
k_EUpdaterState_ClientRestartPending = 6
k_EUpdaterState_SystemRestartPending = 7
k_EStorageBlockContentType_Invalid = 0
k_EStorageBlockContentType_Unknown = 1
k_EStorageBlockContentType_FileSystem = 2
k_EStorageBlockContentType_Crypto = 3
k_EStorageBlockContentType_Raid = 4
k_EStorageBlockFileSystemType_Invalid = 0
k_EStorageBlockFileSystemType_Unknown = 1
k_EStorageBlockFileSystemType_VFat = 2
k_EStorageBlockFileSystemType_Ext4 = 3
k_ESteamDeckCompatibilityCategory_Unknown = 0
k_ESteamDeckCompatibilityCategory_Unsupported = 1
k_ESteamDeckCompatibilityCategory_Playable = 2
k_ESteamDeckCompatibilityCategory_Verified = 3
k_ESteamDeckCompatibilityResultDisplayType_Invisible = 0
k_ESteamDeckCompatibilityResultDisplayType_Informational = 1
k_ESteamDeckCompatibilityResultDisplayType_Unsupported = 2
k_ESteamDeckCompatibilityResultDisplayType_Playable = 3
k_ESteamDeckCompatibilityResultDisplayType_Verified = 4
k_EACState_Unknown = 0
k_EACState_Disconnected = 1
k_EACState_Connected = 2
k_EACState_ConnectedSlow = 3
k_EBatteryState_Unknown = 0
k_EBatteryState_Discharging = 1
k_EBatteryState_Charging = 2
k_EBatteryState_Full = 3
k_EOSBranch_Unknown = 0
k_EOSBranch_Release = 1
k_EOSBranch_ReleaseCandidate = 2
k_EOSBranch_Beta = 3
k_EOSBranch_BetaCandidate = 4
k_EOSBranch_Main = 5
k_ECommunityItemClass_Invalid = 0
k_ECommunityItemClass_Badge = 1
k_ECommunityItemClass_GameCard = 2
k_ECommunityItemClass_ProfileBackground = 3
k_ECommunityItemClass_Emoticon = 4
k_ECommunityItemClass_BoosterPack = 5
k_ECommunityItemClass_Consumable = 6
k_ECommunityItemClass_GameGoo = 7
k_ECommunityItemClass_ProfileModifier = 8
k_ECommunityItemClass_Scene = 9
k_ECommunityItemClass_SalienItem = 10
k_ECommunityItemClass_Sticker = 11
k_ECommunityItemClass_ChatEffect = 12
k_ECommunityItemClass_MiniProfileBackground = 13
k_ECommunityItemClass_AvatarFrame = 14
k_ECommunityItemClass_AnimatedAvatar = 15
k_ECommunityItemClass_SteamDeckKeyboardSkin = 16
k_ESteamDeckCompatibilityFeedback_Unset = 0
k_ESteamDeckCompatibilityFeedback_Agree = 1
k_ESteamDeckCompatibilityFeedback_Disagree = 2
k_ESteamDeckCompatibilityFeedback_Ignore = 3
k_EProvideDeckFeedbackPreference_Unset = 0
k_EProvideDeckFeedbackPreference_Yes = 1
k_EProvideDeckFeedbackPreference_No = 2
k_ETouchGestureNone = 0
k_ETouchGestureTouch = 1
k_ETouchGestureTap = 2
k_ETouchGestureDoubleTap = 3
k_ETouchGestureShortPress = 4
k_ETouchGestureLongPress = 5
k_ETouchGestureLongTap = 6
k_ETouchGestureTwoFingerTap = 7
k_ETouchGestureTapCancelled = 8
k_ETouchGesturePinchBegin = 9
k_ETouchGesturePinchUpdate = 10
k_ETouchGesturePinchEnd = 11
k_ETouchGestureFlingStart = 12
k_ETouchGestureFlingCancelled = 13
k_ESessionPersistence_Invalid = -1
k_ESessionPersistence_Ephemeral = 0
k_ESessionPersistence_Persistent = 1


if _descriptor._USE_C_DESCRIPTORS == False:

    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'H\001\200\001\001\200\265\030\001'
    _EPUBLISHEDFILEQUERYTYPE._serialized_start = 42
    _EPUBLISHEDFILEQUERYTYPE._serialized_end = 1322
    _EPUBLISHEDFILEINAPPROPRIATEPROVIDER._serialized_start = 1325
    _EPUBLISHEDFILEINAPPROPRIATEPROVIDER._serialized_end = 1513
    _EPUBLISHEDFILEINAPPROPRIATERESULT._serialized_start = 1516
    _EPUBLISHEDFILEINAPPROPRIATERESULT._serialized_end = 1857
    _EPERSONASTATEFLAG._serialized_start = 1860
    _EPERSONASTATEFLAG._serialized_end = 2293
    _ECONTENTCHECKPROVIDER._serialized_start = 2296
    _ECONTENTCHECKPROVIDER._serialized_end = 2463
    _EPROFILECUSTOMIZATIONTYPE._serialized_start = 2466
    _EPROFILECUSTOMIZATIONTYPE._serialized_end = 3598
    _EPUBLISHEDFILESTORAGESYSTEM._serialized_start = 3601
    _EPUBLISHEDFILESTORAGESYSTEM._serialized_end = 3801
    _ECLOUDSTORAGEPERSISTSTATE._serialized_start = 3804
    _ECLOUDSTORAGEPERSISTSTATE._serialized_end = 3955
    _ESDCARDFORMATSTAGE._serialized_start = 3958
    _ESDCARDFORMATSTAGE._serialized_end = 4190
    _ESYSTEMFANCONTROLMODE._serialized_start = 4193
    _ESYSTEMFANCONTROLMODE._serialized_end = 4325
    _ECOLORPROFILE._serialized_start = 4328
    _ECOLORPROFILE._serialized_end = 4457
    _EBLUETOOTHDEVICETYPE._serialized_start = 4460
    _EBLUETOOTHDEVICETYPE._serialized_end = 4908
    _ESYSTEMAUDIODIRECTION._serialized_start = 4911
    _ESYSTEMAUDIODIRECTION._serialized_end = 5039
    _ESYSTEMAUDIOCHANNEL._serialized_start = 5042
    _ESYSTEMAUDIOCHANNEL._serialized_end = 5411
    _ESYSTEMAUDIOPORTTYPE._serialized_start = 5414
    _ESYSTEMAUDIOPORTTYPE._serialized_end = 5615
    _ESYSTEMAUDIOPORTDIRECTION._serialized_start = 5618
    _ESYSTEMAUDIOPORTDIRECTION._serialized_end = 5762
    _ESYSTEMSERVICESTATE._serialized_start = 5765
    _ESYSTEMSERVICESTATE._serialized_end = 5896
    _EGRAPHICSPERFOVERLAYLEVEL._serialized_start = 5899
    _EGRAPHICSPERFOVERLAYLEVEL._serialized_end = 6124
    _EGPUPERFORMANCELEVEL._serialized_start = 6127
    _EGPUPERFORMANCELEVEL._serialized_end = 6356
    _ESCALINGFILTER._serialized_start = 6359
    _ESCALINGFILTER._serialized_end = 6546
    _ECPUGOVERNOR._serialized_start = 6548
    _ECPUGOVERNOR._serialized_end = 6672
    _EUPDATERTYPE._serialized_start = 6675
    _EUPDATERTYPE._serialized_end = 6901
    _EUPDATERSTATE._serialized_start = 6904
    _EUPDATERSTATE._serialized_end = 7153
    _ESTORAGEBLOCKCONTENTTYPE._serialized_start = 7156
    _ESTORAGEBLOCKCONTENTTYPE._serialized_end = 7381
    _ESTORAGEBLOCKFILESYSTEMTYPE._serialized_start = 7384
    _ESTORAGEBLOCKFILESYSTEMTYPE._serialized_end = 7579
    _ESTEAMDECKCOMPATIBILITYCATEGORY._serialized_start = 7582
    _ESTEAMDECKCOMPATIBILITYCATEGORY._serialized_end = 7809
    _ESTEAMDECKCOMPATIBILITYRESULTDISPLAYTYPE._serialized_start = 7812
    _ESTEAMDECKCOMPATIBILITYRESULTDISPLAYTYPE._serialized_end = 8148
    _EACSTATE._serialized_start = 8150
    _EACSTATE._serialized_end = 8269
    _EBATTERYSTATE._serialized_start = 8272
    _EBATTERYSTATE._serialized_end = 8405
    _EOSBRANCH._serialized_start = 8408
    _EOSBRANCH._serialized_end = 8578
    _ECOMMUNITYITEMCLASS._serialized_start = 8581
    _ECOMMUNITYITEMCLASS._serialized_end = 9265
    _ESTEAMDECKCOMPATIBILITYFEEDBACK._serialized_start = 9268
    _ESTEAMDECKCOMPATIBILITYFEEDBACK._serialized_end = 9485
    _EPROVIDEDECKFEEDBACKPREFERENCE._serialized_start = 9488
    _EPROVIDEDECKFEEDBACKPREFERENCE._serialized_end = 9647
    _ETOUCHGESTURE._serialized_start = 9650
    _ETOUCHGESTURE._serialized_end = 10083
    _ESESSIONPERSISTENCE._serialized_start = 10086
    _ESESSIONPERSISTENCE._serialized_end = 10226
# @@protoc_insertion_point(module_scope)



from .schemas import (
    AuthenticatorData,
    ServerTime,
    ServerTimeResponse,
)
from .steam import Steam


__all__ = [
    'Steam',
    'AuthenticatorData',
    'ServerTime',
    'ServerTimeResponse',
]



import base64
import binascii
import hashlib
import hmac
import math
from struct import pack
from typing import (
    Any,
    Mapping,
    Optional,
    Type,
)

import rsa
from aiohttp import FormData
from bitstring import BitArray

from pysteamauth.abstract import (
    CookieStorageAbstract,
    RequestStrategyAbstract,
)
from pysteamauth.base import (
    BaseCookieStorage,
    BaseRequestStrategy,
)
from pysteamauth.pb2.enums_pb2 import ESessionPersistence
from pysteamauth.pb2.steammessages_auth.steamclient_pb2 import (
    CAuthentication_AllowedConfirmation,
    CAuthentication_BeginAuthSessionViaCredentials_Request,
    CAuthentication_BeginAuthSessionViaCredentials_Response,
    CAuthentication_GetPasswordRSAPublicKey_Request,
    CAuthentication_GetPasswordRSAPublicKey_Response,
    CAuthentication_PollAuthSessionStatus_Request,
    CAuthentication_PollAuthSessionStatus_Response,
    CAuthentication_UpdateAuthSessionWithSteamGuardCode_Request,
    EAuthSessionGuardType,
    EAuthTokenPlatformType,
)

from .schemas import (
    AuthenticatorData,
    FinalizeLoginStatus,
    ServerTimeResponse,
    SteamAuthorizationStatus,
)
from .utils import get_host_from_url


class Steam:

    domains = (
        'steamcommunity.com',
        'store.steampowered.com',
        'help.steampowered.com',
    )

    def __init__(
        self,
        login: str,
        password: str,
        steamid: int,
        authenticator: Optional[AuthenticatorData] = None,
        cookie_storage: Type[CookieStorageAbstract] = BaseCookieStorage,
        request_strategy: Type[RequestStrategyAbstract] = BaseRequestStrategy,
    ):
        self._login = login
        self._steamid = steamid
        self._password = password
        self._authenticator = authenticator
        self._http = request_strategy()
        self._storage = cookie_storage()

    @property
    def steamid(self) -> int:
        return self._steamid

    @property
    def authenticator(self) -> Optional[AuthenticatorData]:
        return self._authenticator

    @property
    def login(self) -> str:
        return self._login

    async def cookies(self, domain: str = 'steamcommunity.com') -> Mapping[str, str]:
        return await self._storage.get(
            login=self._login,
            domain=domain,
        )

    async def sessionid(self, domain: str = 'steamcommunity.com') -> str:
        return (await self.cookies(domain))['sessionid']

    async def request(self, url: str, method: str = 'GET', **kwargs: Any) -> str:
        """
        Request with Steam session.
        """
        domain = get_host_from_url(url)

        if domain not in self.domains:
            raise RuntimeError(f'Wrong domain "{domain}"')

        cookies = await self._storage.get(
            login=self._login,
            domain=domain,
        )

        return await self._http.text(
            url=url,
            method=method,
            cookies={
                **cookies,
                **kwargs.pop('cookies', {}),
            },
            **kwargs,
        )

    async def is_authorized(self) -> bool:
        """
        Is alive authorization.
        """
        response: str = await self.request(
            url='https://steamcommunity.com/chat/clientjstoken',
        )
        return SteamAuthorizationStatus.parse_raw(response).logged_in

    async def _getrsakey(self) -> CAuthentication_GetPasswordRSAPublicKey_Response:
        """
        Get rsa keys for password encryption.
        """
        message = CAuthentication_GetPasswordRSAPublicKey_Request(
            account_name=self._login,
        )
        response = await self._http.bytes(
            method='GET',
            url='https://api.steampowered.com/IAuthenticationService/GetPasswordRSAPublicKey/v1',
            params={
                'input_protobuf_encoded': str(base64.b64encode(message.SerializeToString()), 'utf8'),
            },
        )
        return CAuthentication_GetPasswordRSAPublicKey_Response.FromString(response)

    async def _begin_auth_session(
            self,
            encrypted_password: str,
            rsa_timestamp: int,
    ) -> CAuthentication_BeginAuthSessionViaCredentials_Response:
        """
        Begin auth session.
        """
        message = CAuthentication_BeginAuthSessionViaCredentials_Request(
            account_name=self._login,
            encrypted_password=encrypted_password,
            encryption_timestamp=rsa_timestamp,
            remember_login=True,
            platform_type=EAuthTokenPlatformType.k_EAuthTokenPlatformType_WebBrowser,
            website_id='Community',
            persistence=ESessionPersistence.k_ESessionPersistence_Persistent,
            device_friendly_name='Mozilla/5.0 (X11; Linux x86_64; rv:1.9.5.20) Gecko/2812-12-10 04:56:28 Firefox/3.8',
        )
        response = await self._http.bytes(
            method='POST',
            url='https://api.steampowered.com/IAuthenticationService/BeginAuthSessionViaCredentials/v1',
            data=FormData(
                fields=[
                    ('input_protobuf_encoded', str(base64.b64encode(message.SerializeToString()), 'utf8')),
                ],
            ),
        )
        return CAuthentication_BeginAuthSessionViaCredentials_Response.FromString(response)

    async def get_server_time(self) -> int:
        """
        Get server time.
        """
        response = await self._http.text(
            method='POST',
            url='https://api.steampowered.com/ITwoFactorService/QueryTime/v0001',
        )
        return ServerTimeResponse.parse_raw(response).response.server_time

    async def get_steam_guard(self, server_time: int) -> str:
        """
        Calculating Steam Guard code.
        """
        if self._authenticator is None:
            raise RuntimeError('Not found authenticator')

        data = binascii.unhexlify(
            hmac.new(
                key=base64.b64decode(self._authenticator.shared_secret),
                msg=pack('!L', 0) + pack('!L', math.floor(server_time // 30)),
                digestmod=hashlib.sha1,
            ).hexdigest(),
        )

        value = data[19] & 0xF
        full_code = (
            (data[value] & 0x7F) << 24 |       # noqa:W504
            (data[value + 1] & 0xFF) << 16 |   # noqa:W504
            (data[value + 2] & 0xFF) << 8 |    # noqa:W504
            (data[value + 3] & 0xFF)
        )

        code = ''
        chars = '23456789BCDFGHJKMNPQRTVWXY'
        for _ in range(5):
            code += chars[full_code % len(chars)]
            full_code //= len(chars)

        return code

    def get_confirmation_hash(self, server_time: int, tag: str = 'conf') -> str:
        """
        Get mobile confirmation hash.
        """
        if self._authenticator is None:
            raise RuntimeError('Not found authenticator')
        identitysecret = base64.b64decode(
            self._authenticator.identity_secret,
        )
        secret = BitArray(
            bytes=identitysecret,
            length=len(identitysecret) * 8,
        )
        tag_buffer = BitArray(
            bytes=tag.encode('utf8'),
            length=len(tag) * 8,
        )
        buffer = BitArray(4 * 8)
        buffer.append(BitArray(int=server_time, length=32))
        buffer.append(tag_buffer)
        confirmation = hmac.new(
            key=secret.tobytes(),
            msg=buffer.tobytes(),
            digestmod=hashlib.sha1,
        )
        return str(base64.b64encode(confirmation.digest()), 'utf8')

    def _encrypt_password(self, keys: CAuthentication_GetPasswordRSAPublicKey_Response) -> str:
        """
        Encrypt password.
        """
        publickey_exp = int(keys.publickey_exp, 16)  # type:ignore
        publickey_mod = int(keys.publickey_mod, 16)  # type:ignore
        public_key = rsa.PublicKey(
            n=publickey_mod,
            e=publickey_exp,
        )
        encrypted_password = rsa.encrypt(
            message=self._password.encode('ascii'),
            pub_key=public_key,
        )
        return str(base64.b64encode(encrypted_password), 'utf8')

    async def _update_auth_session(
            self,
            client_id: int,
            steamid: int,
            code: str,
            code_type: int,
    ) -> None:
        """
        Update session request.
        """
        message = CAuthentication_UpdateAuthSessionWithSteamGuardCode_Request(
            client_id=client_id,
            steamid=steamid,
            code=code,
            code_type=code_type,
        )
        await self._http.request(
            method='POST',
            url='https://api.steampowered.com/IAuthenticationService/UpdateAuthSessionWithSteamGuardCode/v1',
            data=FormData(
                fields=[
                    ('input_protobuf_encoded', str(base64.b64encode(message.SerializeToString()), 'utf8')),
                ],
            ),
        )

    async def _poll_auth_session_status(
            self,
            client_id: int,
            request_id: bytes,
    ) -> CAuthentication_PollAuthSessionStatus_Response:
        """
        Auth session status.
        """
        message = CAuthentication_PollAuthSessionStatus_Request(
            client_id=client_id,
            request_id=request_id,
        )
        response = await self._http.bytes(
            method='POST',
            url='https://api.steampowered.com/IAuthenticationService/PollAuthSessionStatus/v1',
            data=FormData(
                fields=[
                    ('input_protobuf_encoded', str(base64.b64encode(message.SerializeToString()), 'utf8')),
                ],
            ),
        )
        return CAuthentication_PollAuthSessionStatus_Response.FromString(response)

    async def _finalize_login(self, refresh_token: str, sessionid: str) -> FinalizeLoginStatus:
        """
        Finalize login.
        """
        response = await self._http.text(
            method='POST',
            url='https://login.steampowered.com/jwt/finalizelogin',
            data=FormData(
                fields=[
                    ('nonce', refresh_token),
                    ('sessionid', sessionid),
                    ('redir', 'https://steamcommunity.com/login/home/?goto='),
                ],
            ),
        )
        return FinalizeLoginStatus.parse_raw(response)

    async def _set_token(self, url: str, nonce: str, auth: str, steamid: int) -> None:
        """
        Set token.
        """
        await self._http.request(
            method='POST',
            url=url,
            data=FormData(
                fields=[
                    ('nonce', nonce),
                    ('auth', auth),
                    ('steamID', str(steamid)),
                ],
            ),
        )

    def _is_twofactor_required(self, confirmation: CAuthentication_AllowedConfirmation) -> bool:
        """
        Is twofactor required.
        """
        return confirmation.confirmation_type == EAuthSessionGuardType.k_EAuthSessionGuardType_DeviceCode

    async def login_to_steam(self) -> None:
        """
        Login to Steam.
        """
        if await self.is_authorized():
            return
        if not self._http.cookies().get('sessionid'):
            await self._http.bytes(
                method='GET',
                url='https://steamcommunity.com',
            )
        keys = await self._getrsakey()
        encrypted_password = self._encrypt_password(keys)
        auth_session = await self._begin_auth_session(
            encrypted_password=encrypted_password,
            rsa_timestamp=keys.timestamp,
        )
        if auth_session.allowed_confirmations:
            if self._is_twofactor_required(auth_session.allowed_confirmations[0]):
                server_time = await self.get_server_time()
                code = await self.get_steam_guard(server_time)
                await self._update_auth_session(
                    client_id=auth_session.client_id,
                    steamid=auth_session.steamid,
                    code=code,
                    code_type=EAuthSessionGuardType.k_EAuthSessionGuardType_DeviceCode,
                )
        session = await self._poll_auth_session_status(
            client_id=auth_session.client_id,
            request_id=auth_session.request_id,
        )
        tokens = await self._finalize_login(
            refresh_token=session.refresh_token,
            sessionid=self._http.cookies()['sessionid'],
        )

        for token in tokens.transfer_info:
            await self._set_token(
                url=token.url,
                nonce=token.params.nonce,
                auth=token.params.auth,
                steamid=auth_session.steamid,
            )
        # Needs to get additional cookies through aiohttp session
        for domain in ('store', 'help'):
            await self._http.bytes(
                method='GET',
                url=f'https://{domain}.steampowered.com',
            )
        # Write cookies from aiohttp session
        cookies = {}
        for domain in self.domains:
            cookies[domain] = self._http.cookies(domain)
        # Save cookies to storage
        await self._storage.set(login=self._login, cookies=cookies)



from abc import (
    ABC,
    abstractmethod,
)
from typing import Mapping


class CookieStorageAbstract(ABC):

    @abstractmethod
    async def set(self, login: str, cookies: Mapping[str, Mapping[str, str]]) -> None:  # noqa:U100
        ...

    @abstractmethod
    async def get(self, login: str, domain: str = 'steamcommunity.com') -> Mapping[str, str]:  # noqa:U100
        ...



from .enums_pb2 import k_ESessionPersistence_Persistent
from .steammessages_auth.steamclient_pb2 import (
    CAuthentication_BeginAuthSessionViaCredentials_Request,
    CAuthentication_BeginAuthSessionViaCredentials_Response,
    CAuthentication_GetPasswordRSAPublicKey_Request,
    CAuthentication_GetPasswordRSAPublicKey_Response,
    CAuthentication_PollAuthSessionStatus_Request,
    CAuthentication_PollAuthSessionStatus_Response,
    CAuthentication_UpdateAuthSessionWithSteamGuardCode_Request,
    k_EAuthSessionGuardType_DeviceCode,
    k_EAuthTokenPlatformType_WebBrowser,
)


__all__ = [
    'CAuthentication_BeginAuthSessionViaCredentials_Request',
    'CAuthentication_BeginAuthSessionViaCredentials_Response',
    'CAuthentication_GetPasswordRSAPublicKey_Request',
    'CAuthentication_GetPasswordRSAPublicKey_Response',
    'CAuthentication_PollAuthSessionStatus_Request',
    'CAuthentication_PollAuthSessionStatus_Response',
    'CAuthentication_UpdateAuthSessionWithSteamGuardCode_Request',
    'k_EAuthSessionGuardType_DeviceCode',
    'k_EAuthTokenPlatformType_WebBrowser',
    'k_ESessionPersistence_Persistent',
]



import setuptools
from setuptools import setup


requirements = [
    'aiohttp>=3.5.0',
    'protobuf>3.18.3',
    'pydantic>=1.5',
    'rsa>=4.0',
    'bitstring>=3.1.2',
]


setup(
    name='pysteamauth',
    version='0.0.6',
    url='https://github.com/sometastycake/pysteamauth',
    license='MIT',
    author='Mike M',
    author_email='stopthisworldplease@outlook.com',
    description='Asynchronous python library for Steam authorization using protobuf',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    packages=setuptools.find_packages(),
    zip_safe=False,
    python_requires='>=3.7',
    install_requires=requirements,
    setup_requires=requirements,
    include_package_data=True,
)



from typing import (
    Dict,
    Optional,
    Type,
)

from .codes import STEAM_ERROR_CODES


class SteamError(Exception):

    def __init__(self, error_code: int, error_msg: Optional[str] = None):
        self.error_code = error_code
        self.error_msg = error_msg

    def __str__(self) -> str:
        return str({
            'error': STEAM_ERROR_CODES.get(self.error_code, self.error_code),
            'msg': self.error_msg,
            'code': self.error_code,
        })


class UnknownSteamError(SteamError):
    ...


_CUSTOM_ERROR_EXCEPTIONS: Dict[int, Type[SteamError]] = {}


def custom_error_exception(errors: Dict[int, Type[SteamError]]) -> None:
    global _CUSTOM_ERROR_EXCEPTIONS
    if not isinstance(errors, dict):
        raise TypeError('The error argument should be dict')

    for _error, _exception in errors.items():
        if not isinstance(_error, int):
            raise TypeError('Error should be an integer')
        if not isinstance(_exception, type) or not issubclass(_exception, SteamError):
            raise TypeError('Exception should be inherited from SteamError')
        if _error not in STEAM_ERROR_CODES:
            raise TypeError(f'Unknown error code {_error}')
        _CUSTOM_ERROR_EXCEPTIONS[_error] = _exception


class UnauthorizedSteamRequestError(Exception):
    ...


class TooManySteamRequestsError(Exception):
    ...
